/* Generated automatically by the program `gencodes'
   from the machine description file `md'.  */

#ifndef GCC_INSN_CODES_H
#define GCC_INSN_CODES_H

enum insn_code {
  CODE_FOR_nothing = 0,
   CODE_FOR_adddi3_high = CODE_FOR_nothing,
   CODE_FOR_movdf_low_si = CODE_FOR_nothing,
   CODE_FOR_movdf_low_di = CODE_FOR_nothing,
   CODE_FOR_movdf_low_st_si = CODE_FOR_nothing,
   CODE_FOR_movdf_low_st_di = CODE_FOR_nothing,
   CODE_FOR_movsf_low_si = CODE_FOR_nothing,
   CODE_FOR_movsf_low_di = CODE_FOR_nothing,
   CODE_FOR_movsf_low_st_si = CODE_FOR_nothing,
   CODE_FOR_movsf_low_st_di = CODE_FOR_nothing,
   CODE_FOR_movdi_low = CODE_FOR_nothing,
   CODE_FOR_movsi_low_st = CODE_FOR_nothing,
   CODE_FOR_movdi_low_st = CODE_FOR_nothing,
   CODE_FOR_macho_high_si = CODE_FOR_nothing,
   CODE_FOR_macho_high_di = CODE_FOR_nothing,
   CODE_FOR_macho_low_si = CODE_FOR_nothing,
   CODE_FOR_macho_low_di = CODE_FOR_nothing,
  CODE_FOR_load_macho_picbase_si = 1,
  CODE_FOR_load_macho_picbase_di = 2,
  CODE_FOR_macho_correct_pic_si = 3,
  CODE_FOR_macho_correct_pic_di = 4,
  CODE_FOR_reload_macho_picbase_si = 9,
  CODE_FOR_reload_macho_picbase_di = 10,
   CODE_FOR_nonlocal_goto_receiver = CODE_FOR_nothing,
  CODE_FOR_zero_extendqisi2 = 11,
  CODE_FOR_zero_extendqidi2 = 12,
  CODE_FOR_zero_extendhisi2 = 17,
  CODE_FOR_zero_extendhidi2 = 18,
  CODE_FOR_zero_extendsidi2 = 23,
  CODE_FOR_extendqisi2 = 26,
  CODE_FOR_extendqidi2 = 27,
  CODE_FOR_extendsidi2 = 40,
  CODE_FOR_dlmzb = 73,
   CODE_FOR_addsi3_high = CODE_FOR_nothing,
  CODE_FOR_addsi3_carry = 84,
  CODE_FOR_adddi3_carry = 85,
  CODE_FOR_addsi3_carry_in_0 = 96,
  CODE_FOR_adddi3_carry_in_0 = 97,
  CODE_FOR_addsi3_carry_in_m1 = 98,
  CODE_FOR_adddi3_carry_in_m1 = 99,
  CODE_FOR_subfsi3_imm = 112,
  CODE_FOR_subfdi3_imm = 113,
  CODE_FOR_subfsi3_carry_dot2 = 114,
  CODE_FOR_subfdi3_carry_dot2 = 115,
  CODE_FOR_subfsi3_carry = 116,
  CODE_FOR_subfdi3_carry = 117,
  CODE_FOR_subfsi3_carry_in_0 = 124,
  CODE_FOR_subfdi3_carry_in_0 = 125,
  CODE_FOR_subfsi3_carry_in_m1 = 126,
  CODE_FOR_subfdi3_carry_in_m1 = 127,
  CODE_FOR_subfsi3_carry_in_xx = 128,
  CODE_FOR_subfdi3_carry_in_xx = 129,
  CODE_FOR_negsi2 = 130,
  CODE_FOR_negdi2 = 131,
  CODE_FOR_clzsi2 = 136,
  CODE_FOR_clzdi2 = 137,
  CODE_FOR_ctzsi2_hw = 138,
  CODE_FOR_ctzdi2_hw = 139,
  CODE_FOR_popcntbsi2 = 140,
  CODE_FOR_popcntbdi2 = 141,
  CODE_FOR_popcntdsi2 = 142,
  CODE_FOR_popcntddi2 = 143,
  CODE_FOR_paritysi2_cmpb = 144,
  CODE_FOR_paritydi2_cmpb = 145,
  CODE_FOR_cmpbsi3 = 146,
  CODE_FOR_cmpbdi3 = 147,
  CODE_FOR_bswaphi2_load = 151,
  CODE_FOR_bswapsi2_load = 152,
  CODE_FOR_bswaphi2_store = 153,
  CODE_FOR_bswapsi2_store = 154,
  CODE_FOR_bswaphi2_reg = 155,
  CODE_FOR_bswapsi2_reg = 156,
  CODE_FOR_bswapdi2_load = 157,
  CODE_FOR_bswapdi2_store = 158,
  CODE_FOR_bswapdi2_reg = 159,
  CODE_FOR_bswapdi2_32bit = 161,
  CODE_FOR_mulsi3 = 162,
  CODE_FOR_muldi3 = 163,
  CODE_FOR_smulsi3_highpart_le = 172,
  CODE_FOR_umulsi3_highpart_le = 173,
  CODE_FOR_smuldi3_highpart_le = 174,
  CODE_FOR_umuldi3_highpart_le = 175,
  CODE_FOR_smulsi3_highpart_64 = 176,
  CODE_FOR_umulsi3_highpart_64 = 177,
  CODE_FOR_udivsi3 = 179,
  CODE_FOR_udivdi3 = 180,
  CODE_FOR_divsi3_sra = 183,
  CODE_FOR_divdi3_sra = 184,
  CODE_FOR_umodsi3 = 191,
  CODE_FOR_umoddi3 = 192,
  CODE_FOR_andsi3_imm = 193,
  CODE_FOR_anddi3_imm = 194,
  CODE_FOR_andsi3_mask = 205,
  CODE_FOR_anddi3_mask = 206,
  CODE_FOR_rotlsi3 = 258,
  CODE_FOR_rotldi3 = 259,
  CODE_FOR_ashlsi3 = 265,
  CODE_FOR_ashldi3 = 266,
  CODE_FOR_ashdi3_extswsli = 272,
  CODE_FOR_ashdi3_extswsli_dot = 273,
  CODE_FOR_ashdi3_extswsli_dot2 = 274,
  CODE_FOR_lshrsi3 = 275,
  CODE_FOR_lshrdi3 = 276,
  CODE_FOR_ashrsi3 = 282,
  CODE_FOR_ashrdi3 = 283,
  CODE_FOR_fres = 305,
  CODE_FOR_fred = 306,
  CODE_FOR_signbitkf2_dm = 314,
  CODE_FOR_signbittf2_dm = 315,
  CODE_FOR_signbitkf2_dm2 = 320,
  CODE_FOR_signbittf2_dm2 = 321,
  CODE_FOR_copysignsf3_fcpsgn = 322,
  CODE_FOR_copysigndf3_fcpsgn = 323,
  CODE_FOR_isel_signed_si = 332,
  CODE_FOR_isel_signed_di = 333,
  CODE_FOR_isel_unsigned_si = 334,
  CODE_FOR_isel_unsigned_di = 335,
  CODE_FOR_lfiwax = 356,
  CODE_FOR_floatsisf2_lfiwax = 357,
  CODE_FOR_floatsidf2_lfiwax = 358,
  CODE_FOR_floatsisf2_lfiwax_mem = 359,
  CODE_FOR_floatsidf2_lfiwax_mem = 360,
  CODE_FOR_lfiwzx = 361,
  CODE_FOR_floatunssisf2_lfiwzx = 362,
  CODE_FOR_floatunssidf2_lfiwzx = 363,
  CODE_FOR_floatunssisf2_lfiwzx_mem = 364,
  CODE_FOR_floatunssidf2_lfiwzx_mem = 365,
  CODE_FOR_fix_truncsfsi2_stfiwx = 376,
  CODE_FOR_fix_truncdfsi2_stfiwx = 377,
  CODE_FOR_fix_truncsfsi2_internal = 378,
  CODE_FOR_fix_truncdfsi2_internal = 379,
  CODE_FOR_fixuns_truncsfsi2_stfiwx = 386,
  CODE_FOR_fixuns_truncdfsi2_stfiwx = 387,
  CODE_FOR_fixuns_truncsfdi2 = 388,
  CODE_FOR_fixuns_truncdfdi2 = 389,
  CODE_FOR_fctiwz_sf = 402,
  CODE_FOR_fctiwz_df = 403,
  CODE_FOR_fctiwuz_sf = 404,
  CODE_FOR_fctiwuz_df = 405,
  CODE_FOR_lrintsfdi2 = 411,
  CODE_FOR_lrintdfdi2 = 412,
  CODE_FOR_btruncsf2 = 413,
  CODE_FOR_btruncdf2 = 414,
  CODE_FOR_ceilsf2 = 415,
  CODE_FOR_ceildf2 = 416,
  CODE_FOR_floorsf2 = 417,
  CODE_FOR_floordf2 = 418,
  CODE_FOR_roundsf2 = 419,
  CODE_FOR_rounddf2 = 420,
  CODE_FOR_stfiwx = 423,
  CODE_FOR_floatdisf2_fcfids = 428,
  CODE_FOR_floatdisf2_internal1 = 430,
  CODE_FOR_floatunsdisf2_fcfidus = 431,
   CODE_FOR_movsi_low = CODE_FOR_nothing,
  CODE_FOR_movsi_from_sf = 495,
  CODE_FOR_movsf_hardfloat = 502,
  CODE_FOR_movsd_hardfloat = 503,
  CODE_FOR_movsf_from_si = 506,
  CODE_FOR_extenddfif2_fprs = 525,
  CODE_FOR_extenddftf2_fprs = 526,
  CODE_FOR_extenddfif2_vsx = 527,
  CODE_FOR_extenddftf2_vsx = 528,
  CODE_FOR_truncifdf2_internal1 = 529,
  CODE_FOR_trunctfdf2_internal1 = 530,
  CODE_FOR_truncifdf2_internal2 = 531,
  CODE_FOR_trunctfdf2_internal2 = 532,
  CODE_FOR_truncifsf2_fprs = 533,
  CODE_FOR_trunctfsf2_fprs = 534,
  CODE_FOR_fix_trunc_helperif = 535,
  CODE_FOR_fix_trunc_helpertf = 536,
  CODE_FOR_negif2_internal = 539,
  CODE_FOR_negtf2_internal = 540,
  CODE_FOR_ieee_128bit_vsx_negkf2 = 541,
  CODE_FOR_ieee_128bit_vsx_negtf2 = 542,
  CODE_FOR_ieee_128bit_vsx_abskf2 = 545,
  CODE_FOR_ieee_128bit_vsx_abstf2 = 546,
  CODE_FOR_p8_fmrgow_di = 555,
  CODE_FOR_p8_fmrgow_df = 556,
  CODE_FOR_p8_fmrgow_dd = 557,
  CODE_FOR_p8_mtvsrwz = 558,
  CODE_FOR_reload_fpr_from_gprdi = 559,
  CODE_FOR_reload_fpr_from_gprdf = 560,
  CODE_FOR_reload_fpr_from_gprdd = 561,
  CODE_FOR_p8_mtvsrd_df = 562,
  CODE_FOR_p8_xxpermdi_ti = 563,
  CODE_FOR_p8_xxpermdi_v16qi = 564,
  CODE_FOR_p8_xxpermdi_v8hi = 565,
  CODE_FOR_p8_xxpermdi_v4si = 566,
  CODE_FOR_p8_xxpermdi_v4sf = 567,
  CODE_FOR_p8_xxpermdi_v2di = 568,
  CODE_FOR_p8_xxpermdi_v2df = 569,
  CODE_FOR_p8_xxpermdi_v1ti = 570,
  CODE_FOR_p8_xxpermdi_kf = 571,
  CODE_FOR_p8_xxpermdi_tf = 572,
  CODE_FOR_reload_vsx_from_gprti = 573,
  CODE_FOR_reload_vsx_from_gprv16qi = 574,
  CODE_FOR_reload_vsx_from_gprv8hi = 575,
  CODE_FOR_reload_vsx_from_gprv4si = 576,
  CODE_FOR_reload_vsx_from_gprv4sf = 577,
  CODE_FOR_reload_vsx_from_gprv2di = 578,
  CODE_FOR_reload_vsx_from_gprv2df = 579,
  CODE_FOR_reload_vsx_from_gprv1ti = 580,
  CODE_FOR_reload_vsx_from_gprkf = 581,
  CODE_FOR_reload_vsx_from_gprtf = 582,
  CODE_FOR_p8_mtvsrd_sf = 583,
  CODE_FOR_reload_vsx_from_gprsf = 584,
  CODE_FOR_p8_mfvsrd_3_ti = 585,
  CODE_FOR_p8_mfvsrd_3_v16qi = 586,
  CODE_FOR_p8_mfvsrd_3_v8hi = 587,
  CODE_FOR_p8_mfvsrd_3_v4si = 588,
  CODE_FOR_p8_mfvsrd_3_v4sf = 589,
  CODE_FOR_p8_mfvsrd_3_v2di = 590,
  CODE_FOR_p8_mfvsrd_3_v2df = 591,
  CODE_FOR_p8_mfvsrd_3_v1ti = 592,
  CODE_FOR_p8_mfvsrd_3_kf = 593,
  CODE_FOR_p8_mfvsrd_3_tf = 594,
  CODE_FOR_reload_gpr_from_vsxti = 595,
  CODE_FOR_reload_gpr_from_vsxv16qi = 596,
  CODE_FOR_reload_gpr_from_vsxv8hi = 597,
  CODE_FOR_reload_gpr_from_vsxv4si = 598,
  CODE_FOR_reload_gpr_from_vsxv4sf = 599,
  CODE_FOR_reload_gpr_from_vsxv2di = 600,
  CODE_FOR_reload_gpr_from_vsxv2df = 601,
  CODE_FOR_reload_gpr_from_vsxv1ti = 602,
  CODE_FOR_reload_gpr_from_vsxkf = 603,
  CODE_FOR_reload_gpr_from_vsxtf = 604,
  CODE_FOR_reload_gpr_from_vsxsf = 605,
  CODE_FOR_p8_mfvsrd_4_disf = 606,
  CODE_FOR_movdi_si_update = 635,
  CODE_FOR_movdi_di_update = 636,
  CODE_FOR_movdi_si_update_stack = 637,
  CODE_FOR_movdi_di_update_stack = 638,
  CODE_FOR_movsi_update = 641,
  CODE_FOR_movsi_update_stack = 642,
  CODE_FOR_tls_gd_aix32 = 656,
  CODE_FOR_tls_gd_aix64 = 657,
  CODE_FOR_tls_gd_sysvsi = 658,
  CODE_FOR_tls_gd_sysvdi = 659,
  CODE_FOR_tls_ld_aix32 = 670,
  CODE_FOR_tls_ld_aix64 = 671,
  CODE_FOR_tls_ld_sysvsi = 672,
  CODE_FOR_tls_ld_sysvdi = 673,
  CODE_FOR_tls_dtprel_32 = 684,
  CODE_FOR_tls_dtprel_64 = 685,
  CODE_FOR_tls_dtprel_ha_32 = 686,
  CODE_FOR_tls_dtprel_ha_64 = 687,
  CODE_FOR_tls_dtprel_lo_32 = 688,
  CODE_FOR_tls_dtprel_lo_64 = 689,
  CODE_FOR_tls_got_dtprel_32 = 690,
  CODE_FOR_tls_got_dtprel_64 = 691,
  CODE_FOR_tls_tprel_32 = 696,
  CODE_FOR_tls_tprel_64 = 697,
  CODE_FOR_tls_tprel_ha_32 = 698,
  CODE_FOR_tls_tprel_ha_64 = 699,
  CODE_FOR_tls_tprel_lo_32 = 700,
  CODE_FOR_tls_tprel_lo_64 = 701,
  CODE_FOR_tls_got_tprel_32 = 702,
  CODE_FOR_tls_got_tprel_64 = 703,
  CODE_FOR_tls_tls_32 = 708,
  CODE_FOR_tls_tls_64 = 709,
   CODE_FOR_tls_get_tpointer_internal = CODE_FOR_nothing,
   CODE_FOR_tls_get_addr_internalsi = CODE_FOR_nothing,
   CODE_FOR_tls_get_addr_internaldi = CODE_FOR_nothing,
  CODE_FOR_load_toc_aix_si = 710,
  CODE_FOR_load_toc_aix_di = 711,
  CODE_FOR_load_toc_v4_pic_si = 712,
  CODE_FOR_load_toc_v4_PIC_1_normal = 713,
   CODE_FOR_load_toc_v4_PIC_1_476 = CODE_FOR_nothing,
  CODE_FOR_load_toc_v4_PIC_1b_normal = 714,
   CODE_FOR_load_toc_v4_PIC_1b_476 = CODE_FOR_nothing,
  CODE_FOR_load_toc_v4_PIC_2 = 715,
  CODE_FOR_load_toc_v4_PIC_3b = 716,
  CODE_FOR_load_toc_v4_PIC_3c = 717,
  CODE_FOR_elf_high = 723,
  CODE_FOR_elf_low = 724,
  CODE_FOR_blockage = 777,
  CODE_FOR_probe_stack_si = 778,
  CODE_FOR_probe_stack_di = 779,
  CODE_FOR_probe_stack_rangesi = 780,
  CODE_FOR_probe_stack_rangedi = 781,
  CODE_FOR_stack_protect_setsi = 782,
  CODE_FOR_stack_protect_setdi = 783,
  CODE_FOR_stack_protect_testsi = 784,
  CODE_FOR_stack_protect_testdi = 785,
   CODE_FOR_move_from_CR_gt_bit = CODE_FOR_nothing,
  CODE_FOR_move_from_CR_ov_bit = 799,
  CODE_FOR_eqsi3 = 804,
  CODE_FOR_eqdi3 = 805,
  CODE_FOR_nesi3 = 806,
  CODE_FOR_nedi3 = 807,
  CODE_FOR_jump = 832,
  CODE_FOR_return = 833,
  CODE_FOR_simple_return = 834,
  CODE_FOR_indirect_jumpsi_nospec = 837,
  CODE_FOR_indirect_jumpdi_nospec = 838,
  CODE_FOR_nop = 843,
  CODE_FOR_group_ending_nop = 844,
  CODE_FOR_ctrsi_internal1 = 845,
  CODE_FOR_ctrdi_internal1 = 846,
  CODE_FOR_ctrsi_internal2 = 847,
  CODE_FOR_ctrdi_internal2 = 848,
  CODE_FOR_ctrsi_internal3 = 849,
  CODE_FOR_ctrdi_internal3 = 850,
  CODE_FOR_ctrsi_internal4 = 851,
  CODE_FOR_ctrdi_internal4 = 852,
  CODE_FOR_trap = 853,
  CODE_FOR_movesi_from_cr = 857,
  CODE_FOR_stack_tie = 872,
  CODE_FOR_stack_restore_tie = 873,
  CODE_FOR_eh_set_lr_si = 899,
  CODE_FOR_eh_set_lr_di = 900,
  CODE_FOR_prefetch = 901,
  CODE_FOR_load_split_stack_limit_di = 902,
  CODE_FOR_load_split_stack_limit_si = 903,
  CODE_FOR_split_stack_return = 904,
  CODE_FOR_bpermd_si = 905,
  CODE_FOR_bpermd_di = 906,
  CODE_FOR_rs6000_get_timebase_ppc32 = 915,
  CODE_FOR_rs6000_mftb_si = 916,
  CODE_FOR_rs6000_mftb_di = 917,
  CODE_FOR_rs6000_mffs = 918,
  CODE_FOR_rs6000_mtfsf = 919,
  CODE_FOR_fusion_gpr_load_qi = 924,
  CODE_FOR_fusion_gpr_load_hi = 925,
  CODE_FOR_fusion_gpr_load_si = 926,
  CODE_FOR_fusion_gpr_load_di = 927,
  CODE_FOR_fusion_gpr_si_qi_load = 928,
  CODE_FOR_fusion_gpr_di_qi_load = 929,
  CODE_FOR_fusion_gpr_si_hi_load = 930,
  CODE_FOR_fusion_gpr_di_hi_load = 931,
  CODE_FOR_fusion_gpr_si_si_load = 932,
  CODE_FOR_fusion_gpr_di_si_load = 933,
  CODE_FOR_fusion_gpr_si_di_load = 934,
  CODE_FOR_fusion_gpr_di_di_load = 935,
  CODE_FOR_fusion_gpr_si_sf_load = 936,
  CODE_FOR_fusion_gpr_di_sf_load = 937,
  CODE_FOR_fusion_gpr_si_df_load = 938,
  CODE_FOR_fusion_gpr_di_df_load = 939,
  CODE_FOR_fusion_gpr_si_qi_store = 940,
  CODE_FOR_fusion_gpr_di_qi_store = 941,
  CODE_FOR_fusion_gpr_si_hi_store = 942,
  CODE_FOR_fusion_gpr_di_hi_store = 943,
  CODE_FOR_fusion_gpr_si_si_store = 944,
  CODE_FOR_fusion_gpr_di_si_store = 945,
  CODE_FOR_fusion_gpr_si_di_store = 946,
  CODE_FOR_fusion_gpr_di_di_store = 947,
  CODE_FOR_fusion_gpr_si_sf_store = 948,
  CODE_FOR_fusion_gpr_di_sf_store = 949,
  CODE_FOR_fusion_gpr_si_df_store = 950,
  CODE_FOR_fusion_gpr_di_df_store = 951,
  CODE_FOR_fusion_vsx_si_di_load = 952,
  CODE_FOR_fusion_vsx_di_di_load = 953,
  CODE_FOR_fusion_vsx_si_sf_load = 954,
  CODE_FOR_fusion_vsx_di_sf_load = 955,
  CODE_FOR_fusion_vsx_si_df_load = 956,
  CODE_FOR_fusion_vsx_di_df_load = 957,
  CODE_FOR_fusion_vsx_si_di_store = 958,
  CODE_FOR_fusion_vsx_di_di_store = 959,
  CODE_FOR_fusion_vsx_si_sf_store = 960,
  CODE_FOR_fusion_vsx_di_sf_store = 961,
  CODE_FOR_fusion_vsx_si_df_store = 962,
  CODE_FOR_fusion_vsx_di_df_store = 963,
  CODE_FOR_addg6s = 966,
  CODE_FOR_cdtbcd = 967,
  CODE_FOR_cbcdtd = 968,
  CODE_FOR_dive_si = 969,
  CODE_FOR_diveo_si = 970,
  CODE_FOR_diveu_si = 971,
  CODE_FOR_diveuo_si = 972,
  CODE_FOR_dive_di = 973,
  CODE_FOR_diveo_di = 974,
  CODE_FOR_diveu_di = 975,
  CODE_FOR_diveuo_di = 976,
  CODE_FOR_unpacktf_dm = 977,
  CODE_FOR_unpackif_dm = 978,
  CODE_FOR_unpacktd_dm = 979,
  CODE_FOR_unpacktf_nodm = 980,
  CODE_FOR_unpackif_nodm = 981,
  CODE_FOR_unpacktd_nodm = 982,
  CODE_FOR_packtf = 983,
  CODE_FOR_packif = 984,
  CODE_FOR_packtd = 985,
  CODE_FOR_unpackv1ti = 986,
  CODE_FOR_unpackkf = 987,
  CODE_FOR_packv1ti = 988,
  CODE_FOR_packkf = 989,
  CODE_FOR_addkf3 = 990,
  CODE_FOR_addtf3 = 991,
  CODE_FOR_subkf3 = 992,
  CODE_FOR_subtf3 = 993,
  CODE_FOR_mulkf3 = 994,
  CODE_FOR_multf3 = 995,
  CODE_FOR_divkf3 = 996,
  CODE_FOR_divtf3 = 997,
  CODE_FOR_sqrtkf2 = 998,
  CODE_FOR_sqrttf2 = 999,
  CODE_FOR_copysignkf3_hard = 1000,
  CODE_FOR_copysigntf3_hard = 1001,
  CODE_FOR_copysignkf3_soft = 1002,
  CODE_FOR_copysigntf3_soft = 1003,
  CODE_FOR_negkf2_hw = 1004,
  CODE_FOR_negtf2_hw = 1005,
  CODE_FOR_abskf2_hw = 1006,
  CODE_FOR_abstf2_hw = 1007,
  CODE_FOR_extendsfkf2_hw = 1018,
  CODE_FOR_extendsftf2_hw = 1019,
  CODE_FOR_extenddfkf2_hw = 1020,
  CODE_FOR_extenddftf2_hw = 1021,
  CODE_FOR_extendkftf2 = 1022,
  CODE_FOR_trunctfkf2 = 1023,
  CODE_FOR_trunckfdf2_hw = 1024,
  CODE_FOR_trunctfdf2_hw = 1025,
  CODE_FOR_trunckfsf2_hw = 1026,
  CODE_FOR_trunctfsf2_hw = 1027,
  CODE_FOR_fix_kfdi2_hw = 1028,
  CODE_FOR_fix_tfdi2_hw = 1029,
  CODE_FOR_fixuns_kfdi2_hw = 1030,
  CODE_FOR_fixuns_tfdi2_hw = 1031,
  CODE_FOR_fix_kfsi2_hw = 1032,
  CODE_FOR_fix_tfsi2_hw = 1033,
  CODE_FOR_fixuns_kfsi2_hw = 1034,
  CODE_FOR_fixuns_tfsi2_hw = 1035,
  CODE_FOR_float_kfdi2_hw = 1040,
  CODE_FOR_float_tfdi2_hw = 1041,
  CODE_FOR_float_kfsi2_hw = 1042,
  CODE_FOR_float_tfsi2_hw = 1043,
  CODE_FOR_floatqikf2 = 1044,
  CODE_FOR_floatqitf2 = 1045,
  CODE_FOR_floathikf2 = 1046,
  CODE_FOR_floathitf2 = 1047,
  CODE_FOR_floatuns_kfdi2_hw = 1048,
  CODE_FOR_floatuns_tfdi2_hw = 1049,
  CODE_FOR_floatuns_kfsi2_hw = 1050,
  CODE_FOR_floatuns_tfsi2_hw = 1051,
  CODE_FOR_floatunsqikf2 = 1052,
  CODE_FOR_floatunsqitf2 = 1053,
  CODE_FOR_floatunshikf2 = 1054,
  CODE_FOR_floatunshitf2 = 1055,
  CODE_FOR_isync = 1062,
  CODE_FOR_loadsync_qi = 1063,
  CODE_FOR_loadsync_hi = 1064,
  CODE_FOR_loadsync_si = 1065,
  CODE_FOR_loadsync_di = 1066,
  CODE_FOR_loadsync_ti = 1067,
  CODE_FOR_load_quadpti = 1068,
  CODE_FOR_store_quadpti = 1069,
  CODE_FOR_load_lockedqi = 1070,
  CODE_FOR_load_lockedhi = 1071,
  CODE_FOR_load_lockedsi = 1072,
  CODE_FOR_load_lockeddi = 1073,
  CODE_FOR_load_lockedqi_si = 1074,
  CODE_FOR_load_lockedhi_si = 1075,
  CODE_FOR_load_lockedpti = 1076,
  CODE_FOR_store_conditionalqi = 1077,
  CODE_FOR_store_conditionalhi = 1078,
  CODE_FOR_store_conditionalsi = 1079,
  CODE_FOR_store_conditionaldi = 1080,
  CODE_FOR_store_conditionalpti = 1081,
  CODE_FOR_xxspltib_v16qi = 1118,
  CODE_FOR_xxspltib_v8hi_nosplit = 1119,
  CODE_FOR_xxspltib_v4si_nosplit = 1120,
  CODE_FOR_xxspltib_v2di_nosplit = 1121,
  CODE_FOR_vsx_ld_elemrev_v2di = 1145,
  CODE_FOR_vsx_ld_elemrev_v2df = 1146,
  CODE_FOR_vsx_ld_elemrev_v4si = 1147,
  CODE_FOR_vsx_ld_elemrev_v4sf = 1148,
  CODE_FOR_vsx_ld_elemrev_v8hi = 1149,
  CODE_FOR_vsx_ld_elemrev_v16qi = 1150,
  CODE_FOR_vsx_st_elemrev_v2df = 1151,
  CODE_FOR_vsx_st_elemrev_v2di = 1152,
  CODE_FOR_vsx_st_elemrev_v4sf = 1153,
  CODE_FOR_vsx_st_elemrev_v4si = 1154,
  CODE_FOR_vsx_st_elemrev_v8hi = 1155,
  CODE_FOR_vsx_st_elemrev_v16qi = 1156,
  CODE_FOR_vsx_mul_v2di = 1163,
  CODE_FOR_vsx_div_v2di = 1166,
  CODE_FOR_vsx_udiv_v2di = 1167,
  CODE_FOR_vsx_frev4sf2 = 1171,
  CODE_FOR_vsx_frev2df2 = 1172,
  CODE_FOR_vsx_nabsv4sf2 = 1177,
  CODE_FOR_vsx_nabsv2df2 = 1178,
  CODE_FOR_vsx_smaxv4sf3 = 1179,
  CODE_FOR_vsx_smaxv2df3 = 1180,
  CODE_FOR_vsx_eqv4sf = 1198,
  CODE_FOR_vsx_eqv2df = 1199,
  CODE_FOR_vsx_gtv4sf = 1200,
  CODE_FOR_vsx_gtv2df = 1201,
  CODE_FOR_vsx_copysignv4sf3 = 1230,
  CODE_FOR_vsx_copysignv2df3 = 1231,
  CODE_FOR_vsx_floatv4siv4sf2 = 1232,
  CODE_FOR_vsx_floatv2div2df2 = 1233,
  CODE_FOR_vsx_floatunsv4siv4sf2 = 1234,
  CODE_FOR_vsx_floatunsv2div2df2 = 1235,
  CODE_FOR_vsx_fix_truncv4sfv4si2 = 1236,
  CODE_FOR_vsx_fix_truncv2dfv2di2 = 1237,
  CODE_FOR_vsx_fixuns_truncv4sfv4si2 = 1238,
  CODE_FOR_vsx_fixuns_truncv2dfv2di2 = 1239,
  CODE_FOR_vsx_xsrdpi = 1240,
  CODE_FOR_vsx_xvrspi = 1241,
  CODE_FOR_vsx_xvrdpi = 1242,
  CODE_FOR_vsx_xsrdpic = 1243,
  CODE_FOR_vsx_xvrspic = 1244,
  CODE_FOR_vsx_xvrdpic = 1245,
  CODE_FOR_vsx_btruncv4sf2 = 1246,
  CODE_FOR_vsx_btruncv2df2 = 1247,
  CODE_FOR_vsx_floorv4sf2 = 1251,
  CODE_FOR_vsx_floorv2df2 = 1252,
  CODE_FOR_vsx_ceilv4sf2 = 1253,
  CODE_FOR_vsx_ceilv2df2 = 1254,
  CODE_FOR_vsx_xscvdpsp = 1255,
  CODE_FOR_vsx_xvcvspdp = 1256,
  CODE_FOR_vsx_xvcvdpsp = 1257,
  CODE_FOR_vsx_xscvspdp = 1258,
  CODE_FOR_vsx_xscvdpsp_scalar = 1259,
  CODE_FOR_vsx_xscvspdp_scalar2 = 1260,
  CODE_FOR_vsx_xscvdpspn = 1261,
  CODE_FOR_vsx_xscvspdpn = 1262,
  CODE_FOR_vsx_xscvdpspn_scalar = 1263,
  CODE_FOR_vsx_xscvspdpn_directmove = 1264,
  CODE_FOR_vsx_xvcvsxddp = 1265,
  CODE_FOR_vsx_xvcvuxddp = 1266,
  CODE_FOR_vsx_xvcvdpsxds = 1267,
  CODE_FOR_vsx_xvcvdpuxds = 1268,
  CODE_FOR_vsx_xvcvdpsxws = 1269,
  CODE_FOR_vsx_xvcvdpuxws = 1270,
  CODE_FOR_vsx_xvcvsxdsp = 1271,
  CODE_FOR_vsx_xvcvuxdsp = 1272,
  CODE_FOR_vsx_xvcvsxwdp = 1273,
  CODE_FOR_vsx_xvcvsxwdp_df = 1274,
  CODE_FOR_vsx_xvcvuxwdp = 1275,
  CODE_FOR_vsx_xvcvuxwdp_df = 1276,
  CODE_FOR_vsx_xvcvspsxds = 1277,
  CODE_FOR_vsx_xvcvspuxds = 1278,
  CODE_FOR_vsx_concat_v2df = 1280,
  CODE_FOR_vsx_concat_v2di = 1281,
  CODE_FOR_vsx_concat_v2sf = 1288,
  CODE_FOR_vsx_init_v4si = 1289,
  CODE_FOR_vsx_extract_v2df = 1308,
  CODE_FOR_vsx_extract_v2di = 1309,
  CODE_FOR_vsx_vslo_v2df = 1316,
  CODE_FOR_vsx_vslo_v2di = 1317,
  CODE_FOR_vsx_extract_v2df_var = 1318,
  CODE_FOR_vsx_extract_v2di_var = 1319,
  CODE_FOR_vsx_extract_v4sf = 1320,
  CODE_FOR_vsx_extract_v4sf_var = 1323,
  CODE_FOR_vsx_xxpermdi2_v2df_1 = 1324,
  CODE_FOR_vsx_xxpermdi2_v2di_1 = 1325,
  CODE_FOR_vsx_extract_v16qi_p9 = 1326,
  CODE_FOR_vsx_extract_v8hi_p9 = 1327,
  CODE_FOR_vsx_extract_v4si_p9 = 1328,
  CODE_FOR_vsx_extract_v16qi_var = 1341,
  CODE_FOR_vsx_extract_v8hi_var = 1342,
  CODE_FOR_vsx_extract_v4si_var = 1343,
  CODE_FOR_vsx_set_v16qi_p9 = 1384,
  CODE_FOR_vsx_set_v8hi_p9 = 1385,
  CODE_FOR_vsx_set_v4si_p9 = 1386,
  CODE_FOR_vsx_set_v4sf_p9 = 1387,
  CODE_FOR_vsx_splat_v2df = 1391,
  CODE_FOR_vsx_splat_v2di = 1392,
  CODE_FOR_vsx_splat_v4si = 1393,
  CODE_FOR_vsx_splat_v4si_di = 1394,
  CODE_FOR_vsx_splat_v4sf = 1395,
  CODE_FOR_vsx_xxspltw_v4sf = 1396,
  CODE_FOR_vsx_xxspltw_v4si = 1397,
  CODE_FOR_vsx_xxspltw_v4sf_direct = 1398,
  CODE_FOR_vsx_xxspltw_v4si_direct = 1399,
  CODE_FOR_vsx_vspltb_di = 1400,
  CODE_FOR_vsx_vsplth_di = 1401,
  CODE_FOR_vsx_xxspltd_v2df = 1402,
  CODE_FOR_vsx_xxspltd_v2di = 1403,
  CODE_FOR_vsx_xxmrghw_v4sf = 1404,
  CODE_FOR_vsx_xxmrghw_v4si = 1405,
  CODE_FOR_vsx_xxmrglw_v4sf = 1406,
  CODE_FOR_vsx_xxmrglw_v4si = 1407,
  CODE_FOR_vsx_xxsldwi_v16qi = 1408,
  CODE_FOR_vsx_xxsldwi_v8hi = 1409,
  CODE_FOR_vsx_xxsldwi_v4si = 1410,
  CODE_FOR_vsx_xxsldwi_v2di = 1411,
  CODE_FOR_vsx_xxsldwi_v4sf = 1412,
  CODE_FOR_vsx_xxsldwi_v2df = 1413,
  CODE_FOR_vsx_xxsldwi_v1ti = 1414,
  CODE_FOR_vsx_xxsldwi_ti = 1415,
  CODE_FOR_vsx_xxsldwi_kf = 1416,
  CODE_FOR_vsx_xxsldwi_tf = 1417,
  CODE_FOR_vsx_reduc_plus_v2df = 1418,
  CODE_FOR_vsx_reduc_smin_v2df = 1419,
  CODE_FOR_vsx_reduc_smax_v2df = 1420,
  CODE_FOR_vsx_reduc_plus_v4sf = 1421,
  CODE_FOR_vsx_reduc_smin_v4sf = 1422,
  CODE_FOR_vsx_reduc_smax_v4sf = 1423,
  CODE_FOR_vsx_sign_extend_qi_v4si = 1430,
  CODE_FOR_vsx_sign_extend_qi_v2di = 1431,
  CODE_FOR_vsx_sign_extend_qi_di = 1432,
  CODE_FOR_vsx_sign_extend_qi_si = 1433,
  CODE_FOR_vsx_sign_extend_hi_v4si = 1434,
  CODE_FOR_vsx_sign_extend_hi_v2di = 1435,
  CODE_FOR_vsx_sign_extend_hi_di = 1436,
  CODE_FOR_vsx_sign_extend_hi_si = 1437,
  CODE_FOR_xsxexpdp = 1439,
  CODE_FOR_xsxsigdp = 1440,
  CODE_FOR_xsiexpdp = 1441,
  CODE_FOR_xsiexpdpf = 1442,
  CODE_FOR_xvxexpsp = 1446,
  CODE_FOR_xvxexpdp = 1447,
  CODE_FOR_xvxsigsp = 1448,
  CODE_FOR_xvxsigdp = 1449,
  CODE_FOR_xviexpsp = 1450,
  CODE_FOR_xviexpdp = 1451,
  CODE_FOR_xvtstdcsp = 1452,
  CODE_FOR_xvtstdcdp = 1453,
  CODE_FOR_vcmpneb = 1462,
  CODE_FOR_vcmpnezb = 1463,
  CODE_FOR_vcmpneh = 1464,
  CODE_FOR_vcmpnezh = 1465,
  CODE_FOR_vcmpnew = 1466,
  CODE_FOR_vcmpnezw = 1467,
  CODE_FOR_vclzlsbb = 1468,
  CODE_FOR_vctzlsbb = 1469,
  CODE_FOR_vextublx = 1470,
  CODE_FOR_vextubrx = 1471,
  CODE_FOR_vextuhlx = 1472,
  CODE_FOR_vextuhrx = 1473,
  CODE_FOR_vextuwlx = 1474,
  CODE_FOR_vextuwrx = 1475,
  CODE_FOR_p9_xxbrq_v1ti = 1479,
  CODE_FOR_p9_xxbrd_v2df = 1480,
  CODE_FOR_p9_xxbrd_v2di = 1481,
  CODE_FOR_p9_xxbrw_v4sf = 1482,
  CODE_FOR_p9_xxbrw_v4si = 1483,
  CODE_FOR_p9_xxbrh_v8hi = 1484,
  CODE_FOR_get_vrsave_internal = 1495,
  CODE_FOR_addv4si3 = 1505,
  CODE_FOR_addv8hi3 = 1506,
  CODE_FOR_addv16qi3 = 1507,
  CODE_FOR_addv2di3 = 1508,
  CODE_FOR_altivec_vaddcuw = 1510,
  CODE_FOR_altivec_vadduws = 1511,
  CODE_FOR_altivec_vadduhs = 1512,
  CODE_FOR_altivec_vaddubs = 1513,
  CODE_FOR_altivec_vaddsws = 1514,
  CODE_FOR_altivec_vaddshs = 1515,
  CODE_FOR_altivec_vaddsbs = 1516,
  CODE_FOR_subv4si3 = 1517,
  CODE_FOR_subv8hi3 = 1518,
  CODE_FOR_subv16qi3 = 1519,
  CODE_FOR_subv2di3 = 1520,
  CODE_FOR_altivec_vsubcuw = 1522,
  CODE_FOR_altivec_vsubuws = 1523,
  CODE_FOR_altivec_vsubuhs = 1524,
  CODE_FOR_altivec_vsububs = 1525,
  CODE_FOR_altivec_vsubsws = 1526,
  CODE_FOR_altivec_vsubshs = 1527,
  CODE_FOR_altivec_vsubsbs = 1528,
  CODE_FOR_altivec_vavguw = 1529,
  CODE_FOR_altivec_vavguh = 1530,
  CODE_FOR_altivec_vavgub = 1531,
  CODE_FOR_altivec_vavgsw = 1532,
  CODE_FOR_altivec_vavgsh = 1533,
  CODE_FOR_altivec_vavgsb = 1534,
  CODE_FOR_altivec_vcmpbfp = 1535,
  CODE_FOR_mulv4si3_p8 = 1572,
  CODE_FOR_altivec_vmsumuhm = 1574,
  CODE_FOR_altivec_vmsumubm = 1575,
  CODE_FOR_altivec_vmsummhm = 1576,
  CODE_FOR_altivec_vmsummbm = 1577,
  CODE_FOR_altivec_vmsumshm = 1578,
  CODE_FOR_altivec_vmsumuhs = 1579,
  CODE_FOR_altivec_vmsumshs = 1580,
  CODE_FOR_umaxv4si3 = 1581,
  CODE_FOR_umaxv8hi3 = 1582,
  CODE_FOR_umaxv16qi3 = 1583,
  CODE_FOR_umaxv2di3 = 1584,
  CODE_FOR_smaxv4si3 = 1585,
  CODE_FOR_smaxv8hi3 = 1586,
  CODE_FOR_smaxv16qi3 = 1587,
  CODE_FOR_smaxv2di3 = 1588,
  CODE_FOR_uminv4si3 = 1590,
  CODE_FOR_uminv8hi3 = 1591,
  CODE_FOR_uminv16qi3 = 1592,
  CODE_FOR_uminv2di3 = 1593,
  CODE_FOR_sminv4si3 = 1594,
  CODE_FOR_sminv8hi3 = 1595,
  CODE_FOR_sminv16qi3 = 1596,
  CODE_FOR_sminv2di3 = 1597,
  CODE_FOR_altivec_vmhaddshs = 1599,
  CODE_FOR_altivec_vmhraddshs = 1600,
  CODE_FOR_altivec_vmladduhm = 1601,
  CODE_FOR_altivec_vmrghb_direct = 1603,
  CODE_FOR_altivec_vmrghh_direct = 1605,
  CODE_FOR_altivec_vmrghw_direct = 1607,
  CODE_FOR_altivec_vmrglb_direct = 1610,
  CODE_FOR_altivec_vmrglh_direct = 1612,
  CODE_FOR_altivec_vmrglw_direct = 1614,
  CODE_FOR_p8_vmrgew = 1616,
  CODE_FOR_p8_vmrgow = 1617,
  CODE_FOR_p8_vmrgew_v4sf_direct = 1618,
  CODE_FOR_altivec_vmuleub = 1619,
  CODE_FOR_altivec_vmuloub = 1620,
  CODE_FOR_altivec_vmulesb = 1621,
  CODE_FOR_altivec_vmulosb = 1622,
  CODE_FOR_altivec_vmuleuh = 1623,
  CODE_FOR_altivec_vmulouh = 1624,
  CODE_FOR_altivec_vmulesh = 1625,
  CODE_FOR_altivec_vmulosh = 1626,
  CODE_FOR_altivec_vpkpx = 1627,
  CODE_FOR_altivec_vpksdss = 1628,
  CODE_FOR_altivec_vpkswss = 1629,
  CODE_FOR_altivec_vpkshss = 1630,
  CODE_FOR_altivec_vpksdus = 1631,
  CODE_FOR_altivec_vpkswus = 1632,
  CODE_FOR_altivec_vpkshus = 1633,
  CODE_FOR_altivec_vpkudus = 1634,
  CODE_FOR_altivec_vpkuwus = 1635,
  CODE_FOR_altivec_vpkuhus = 1636,
  CODE_FOR_altivec_vpkudum = 1637,
  CODE_FOR_altivec_vpkuwum = 1638,
  CODE_FOR_altivec_vpkuhum = 1639,
  CODE_FOR_altivec_vpkudum_direct = 1640,
  CODE_FOR_altivec_vpkuwum_direct = 1641,
  CODE_FOR_altivec_vpkuhum_direct = 1642,
  CODE_FOR_altivec_vrldmi = 1647,
  CODE_FOR_altivec_vrlwmi = 1648,
  CODE_FOR_altivec_vrldnm = 1649,
  CODE_FOR_altivec_vrlwnm = 1650,
  CODE_FOR_altivec_vsl = 1651,
  CODE_FOR_altivec_vslo = 1652,
  CODE_FOR_vslv = 1653,
  CODE_FOR_vsrv = 1654,
  CODE_FOR_altivec_vsr = 1667,
  CODE_FOR_altivec_vsro = 1668,
  CODE_FOR_altivec_vsum4ubs = 1669,
  CODE_FOR_altivec_vsum4shs = 1670,
  CODE_FOR_altivec_vsum4sbs = 1671,
  CODE_FOR_altivec_vsum2sws_direct = 1672,
  CODE_FOR_altivec_vsumsws_direct = 1673,
  CODE_FOR_altivec_vspltb_direct = 1675,
  CODE_FOR_altivec_vsplth_direct = 1677,
  CODE_FOR_altivec_vspltw_direct = 1679,
  CODE_FOR_altivec_vspltisw = 1681,
  CODE_FOR_altivec_vspltish = 1682,
  CODE_FOR_altivec_vspltisb = 1683,
  CODE_FOR_altivec_vperm_v8hiv16qi = 1695,
  CODE_FOR_altivec_vrfip = 1716,
  CODE_FOR_altivec_vrfin = 1717,
  CODE_FOR_altivec_vcfux = 1719,
  CODE_FOR_altivec_vcfsx = 1720,
  CODE_FOR_altivec_vctuxs = 1721,
  CODE_FOR_altivec_vctsxs = 1722,
  CODE_FOR_altivec_vlogefp = 1723,
  CODE_FOR_altivec_vexptefp = 1724,
  CODE_FOR_altivec_vrefp = 1726,
  CODE_FOR_altivec_vsldoi_v4si = 1727,
  CODE_FOR_altivec_vsldoi_v8hi = 1728,
  CODE_FOR_altivec_vsldoi_v16qi = 1729,
  CODE_FOR_altivec_vsldoi_v4sf = 1730,
  CODE_FOR_altivec_vsldoi_v2df = 1731,
  CODE_FOR_altivec_vsldoi_v2di = 1732,
  CODE_FOR_altivec_vsldoi_v1ti = 1733,
  CODE_FOR_altivec_vsldoi_ti = 1734,
  CODE_FOR_altivec_vsldoi_kf = 1735,
  CODE_FOR_altivec_vsldoi_tf = 1736,
  CODE_FOR_altivec_vupkhsw = 1737,
  CODE_FOR_altivec_vupkhsh = 1738,
  CODE_FOR_altivec_vupkhsb = 1739,
  CODE_FOR_altivec_vupklsw = 1743,
  CODE_FOR_altivec_vupklsh = 1744,
  CODE_FOR_altivec_vupklsb = 1745,
  CODE_FOR_altivec_vupkhpx = 1749,
  CODE_FOR_altivec_vupklpx = 1750,
  CODE_FOR_altivec_vcmpbfp_p = 1766,
  CODE_FOR_altivec_mtvscr = 1767,
  CODE_FOR_altivec_mfvscr = 1768,
  CODE_FOR_altivec_dssall = 1769,
  CODE_FOR_altivec_dss = 1770,
  CODE_FOR_altivec_dst = 1771,
  CODE_FOR_altivec_dstt = 1772,
  CODE_FOR_altivec_dstst = 1773,
  CODE_FOR_altivec_dststt = 1774,
  CODE_FOR_altivec_lvsl_direct = 1775,
  CODE_FOR_altivec_lvsr_direct = 1776,
  CODE_FOR_altivec_lvx_v4si_internal = 1790,
  CODE_FOR_altivec_lvx_v8hi_internal = 1791,
  CODE_FOR_altivec_lvx_v16qi_internal = 1792,
  CODE_FOR_altivec_lvx_v4sf_internal = 1793,
  CODE_FOR_altivec_lvx_v2df_internal = 1794,
  CODE_FOR_altivec_lvx_v2di_internal = 1795,
  CODE_FOR_altivec_lvx_v1ti_internal = 1796,
  CODE_FOR_altivec_lvx_kf_internal = 1797,
  CODE_FOR_altivec_lvx_tf_internal = 1798,
  CODE_FOR_altivec_lvx_v4si_2op = 1799,
  CODE_FOR_altivec_lvx_v8hi_2op = 1800,
  CODE_FOR_altivec_lvx_v16qi_2op = 1801,
  CODE_FOR_altivec_lvx_v4sf_2op = 1802,
  CODE_FOR_altivec_lvx_v2df_2op = 1803,
  CODE_FOR_altivec_lvx_v2di_2op = 1804,
  CODE_FOR_altivec_lvx_v1ti_2op = 1805,
  CODE_FOR_altivec_lvx_kf_2op = 1806,
  CODE_FOR_altivec_lvx_tf_2op = 1807,
  CODE_FOR_altivec_lvx_v4si_1op = 1808,
  CODE_FOR_altivec_lvx_v8hi_1op = 1809,
  CODE_FOR_altivec_lvx_v16qi_1op = 1810,
  CODE_FOR_altivec_lvx_v4sf_1op = 1811,
  CODE_FOR_altivec_lvx_v2df_1op = 1812,
  CODE_FOR_altivec_lvx_v2di_1op = 1813,
  CODE_FOR_altivec_lvx_v1ti_1op = 1814,
  CODE_FOR_altivec_lvx_kf_1op = 1815,
  CODE_FOR_altivec_lvx_tf_1op = 1816,
  CODE_FOR_altivec_lvx_v4si_2op_si = 1817,
  CODE_FOR_altivec_lvx_v8hi_2op_si = 1818,
  CODE_FOR_altivec_lvx_v16qi_2op_si = 1819,
  CODE_FOR_altivec_lvx_v4sf_2op_si = 1820,
  CODE_FOR_altivec_lvx_v2df_2op_si = 1821,
  CODE_FOR_altivec_lvx_v2di_2op_si = 1822,
  CODE_FOR_altivec_lvx_v1ti_2op_si = 1823,
  CODE_FOR_altivec_lvx_kf_2op_si = 1824,
  CODE_FOR_altivec_lvx_tf_2op_si = 1825,
  CODE_FOR_altivec_lvx_v4si_1op_si = 1826,
  CODE_FOR_altivec_lvx_v8hi_1op_si = 1827,
  CODE_FOR_altivec_lvx_v16qi_1op_si = 1828,
  CODE_FOR_altivec_lvx_v4sf_1op_si = 1829,
  CODE_FOR_altivec_lvx_v2df_1op_si = 1830,
  CODE_FOR_altivec_lvx_v2di_1op_si = 1831,
  CODE_FOR_altivec_lvx_v1ti_1op_si = 1832,
  CODE_FOR_altivec_lvx_kf_1op_si = 1833,
  CODE_FOR_altivec_lvx_tf_1op_si = 1834,
  CODE_FOR_altivec_stvx_v4si_internal = 1835,
  CODE_FOR_altivec_stvx_v8hi_internal = 1836,
  CODE_FOR_altivec_stvx_v16qi_internal = 1837,
  CODE_FOR_altivec_stvx_v4sf_internal = 1838,
  CODE_FOR_altivec_stvx_v2df_internal = 1839,
  CODE_FOR_altivec_stvx_v2di_internal = 1840,
  CODE_FOR_altivec_stvx_v1ti_internal = 1841,
  CODE_FOR_altivec_stvx_kf_internal = 1842,
  CODE_FOR_altivec_stvx_tf_internal = 1843,
  CODE_FOR_altivec_stvx_v4si_2op = 1844,
  CODE_FOR_altivec_stvx_v8hi_2op = 1845,
  CODE_FOR_altivec_stvx_v16qi_2op = 1846,
  CODE_FOR_altivec_stvx_v4sf_2op = 1847,
  CODE_FOR_altivec_stvx_v2df_2op = 1848,
  CODE_FOR_altivec_stvx_v2di_2op = 1849,
  CODE_FOR_altivec_stvx_v1ti_2op = 1850,
  CODE_FOR_altivec_stvx_kf_2op = 1851,
  CODE_FOR_altivec_stvx_tf_2op = 1852,
  CODE_FOR_altivec_stvx_v4si_1op = 1853,
  CODE_FOR_altivec_stvx_v8hi_1op = 1854,
  CODE_FOR_altivec_stvx_v16qi_1op = 1855,
  CODE_FOR_altivec_stvx_v4sf_1op = 1856,
  CODE_FOR_altivec_stvx_v2df_1op = 1857,
  CODE_FOR_altivec_stvx_v2di_1op = 1858,
  CODE_FOR_altivec_stvx_v1ti_1op = 1859,
  CODE_FOR_altivec_stvx_kf_1op = 1860,
  CODE_FOR_altivec_stvx_tf_1op = 1861,
  CODE_FOR_altivec_stvx_v4si_2op_si = 1862,
  CODE_FOR_altivec_stvx_v8hi_2op_si = 1863,
  CODE_FOR_altivec_stvx_v16qi_2op_si = 1864,
  CODE_FOR_altivec_stvx_v4sf_2op_si = 1865,
  CODE_FOR_altivec_stvx_v2df_2op_si = 1866,
  CODE_FOR_altivec_stvx_v2di_2op_si = 1867,
  CODE_FOR_altivec_stvx_v1ti_2op_si = 1868,
  CODE_FOR_altivec_stvx_kf_2op_si = 1869,
  CODE_FOR_altivec_stvx_tf_2op_si = 1870,
  CODE_FOR_altivec_stvx_v4si_1op_si = 1871,
  CODE_FOR_altivec_stvx_v8hi_1op_si = 1872,
  CODE_FOR_altivec_stvx_v16qi_1op_si = 1873,
  CODE_FOR_altivec_stvx_v4sf_1op_si = 1874,
  CODE_FOR_altivec_stvx_v2df_1op_si = 1875,
  CODE_FOR_altivec_stvx_v2di_1op_si = 1876,
  CODE_FOR_altivec_stvx_v1ti_1op_si = 1877,
  CODE_FOR_altivec_stvx_kf_1op_si = 1878,
  CODE_FOR_altivec_stvx_tf_1op_si = 1879,
  CODE_FOR_vperm_v8hiv4si = 1895,
  CODE_FOR_vperm_v16qiv8hi = 1896,
  CODE_FOR_altivec_lvlx = 1897,
  CODE_FOR_altivec_lvlxl = 1898,
  CODE_FOR_altivec_lvrx = 1899,
  CODE_FOR_altivec_lvrxl = 1900,
  CODE_FOR_altivec_stvlx = 1901,
  CODE_FOR_altivec_stvlxl = 1902,
  CODE_FOR_altivec_stvrx = 1903,
  CODE_FOR_altivec_stvrxl = 1904,
  CODE_FOR_p8v_vgbbd = 1924,
  CODE_FOR_altivec_vadduqm = 1925,
  CODE_FOR_altivec_vaddcuq = 1926,
  CODE_FOR_altivec_vsubuqm = 1927,
  CODE_FOR_altivec_vsubcuq = 1928,
  CODE_FOR_altivec_vaddeuqm = 1929,
  CODE_FOR_altivec_vaddecuq = 1930,
  CODE_FOR_altivec_vsubeuqm = 1931,
  CODE_FOR_altivec_vsubecuq = 1932,
  CODE_FOR_altivec_vbpermq = 1933,
  CODE_FOR_altivec_vbpermq2 = 1934,
  CODE_FOR_altivec_vbpermd = 1935,
  CODE_FOR_bcdadd = 1936,
  CODE_FOR_bcdsub = 1937,
  CODE_FOR_darn_32 = 1942,
  CODE_FOR_darn_raw = 1943,
  CODE_FOR_darn = 1944,
  CODE_FOR_setb_signed = 1946,
  CODE_FOR_setb_unsigned = 1947,
   CODE_FOR_spe_fixuns_truncdfsi2 = CODE_FOR_nothing,
   CODE_FOR_spe_extendsfdf2 = CODE_FOR_nothing,
   CODE_FOR_spe_fixuns_truncsfsi2 = CODE_FOR_nothing,
   CODE_FOR_spe_fix_truncsfsi2 = CODE_FOR_nothing,
   CODE_FOR_spe_fix_truncdfsi2 = CODE_FOR_nothing,
   CODE_FOR_spe_floatunssisf2 = CODE_FOR_nothing,
   CODE_FOR_spe_floatunssidf2 = CODE_FOR_nothing,
   CODE_FOR_spe_floatsisf2 = CODE_FOR_nothing,
   CODE_FOR_spe_floatsidf2 = CODE_FOR_nothing,
   CODE_FOR_absv2si2 = CODE_FOR_nothing,
   CODE_FOR_spe_evandc = CODE_FOR_nothing,
   CODE_FOR_andv2si3 = CODE_FOR_nothing,
   CODE_FOR_spe_evcmpeq = CODE_FOR_nothing,
   CODE_FOR_spe_evcmpgts = CODE_FOR_nothing,
   CODE_FOR_spe_evcmpgtu = CODE_FOR_nothing,
   CODE_FOR_spe_evcmplts = CODE_FOR_nothing,
   CODE_FOR_spe_evcmpltu = CODE_FOR_nothing,
   CODE_FOR_spe_evfscmpeq = CODE_FOR_nothing,
   CODE_FOR_spe_evfscmpgt = CODE_FOR_nothing,
   CODE_FOR_spe_evfscmplt = CODE_FOR_nothing,
   CODE_FOR_spe_evfststeq = CODE_FOR_nothing,
   CODE_FOR_spe_evfststgt = CODE_FOR_nothing,
   CODE_FOR_spe_evfststlt = CODE_FOR_nothing,
   CODE_FOR_spe_evcntlsw = CODE_FOR_nothing,
   CODE_FOR_spe_evcntlzw = CODE_FOR_nothing,
   CODE_FOR_spe_eveqv = CODE_FOR_nothing,
   CODE_FOR_spe_evextsb = CODE_FOR_nothing,
   CODE_FOR_spe_evextsh = CODE_FOR_nothing,
   CODE_FOR_spe_evlhhesplat = CODE_FOR_nothing,
   CODE_FOR_spe_evlhhesplatx = CODE_FOR_nothing,
   CODE_FOR_spe_evlhhossplat = CODE_FOR_nothing,
   CODE_FOR_spe_evlhhossplatx = CODE_FOR_nothing,
   CODE_FOR_spe_evlhhousplat = CODE_FOR_nothing,
   CODE_FOR_spe_evlhhousplatx = CODE_FOR_nothing,
   CODE_FOR_spe_evlwhsplat = CODE_FOR_nothing,
   CODE_FOR_spe_evlwhsplatx = CODE_FOR_nothing,
   CODE_FOR_spe_evlwwsplat = CODE_FOR_nothing,
   CODE_FOR_spe_evlwwsplatx = CODE_FOR_nothing,
   CODE_FOR_vec_perm00_v2si = CODE_FOR_nothing,
   CODE_FOR_vec_perm01_v2si = CODE_FOR_nothing,
   CODE_FOR_vec_perm11_v2si = CODE_FOR_nothing,
   CODE_FOR_vec_perm10_v2si = CODE_FOR_nothing,
   CODE_FOR_spe_evnand = CODE_FOR_nothing,
   CODE_FOR_negv2si2 = CODE_FOR_nothing,
   CODE_FOR_spe_evnor = CODE_FOR_nothing,
   CODE_FOR_spe_evorc = CODE_FOR_nothing,
   CODE_FOR_spe_evor = CODE_FOR_nothing,
   CODE_FOR_spe_evrlwi = CODE_FOR_nothing,
   CODE_FOR_spe_evrlw = CODE_FOR_nothing,
   CODE_FOR_spe_evrndw = CODE_FOR_nothing,
   CODE_FOR_spe_evsel = CODE_FOR_nothing,
   CODE_FOR_spe_evsel_fs = CODE_FOR_nothing,
   CODE_FOR_spe_evslwi = CODE_FOR_nothing,
   CODE_FOR_spe_evslw = CODE_FOR_nothing,
   CODE_FOR_spe_evsrwis = CODE_FOR_nothing,
   CODE_FOR_spe_evsrwiu = CODE_FOR_nothing,
   CODE_FOR_spe_evsrws = CODE_FOR_nothing,
   CODE_FOR_spe_evsrwu = CODE_FOR_nothing,
   CODE_FOR_xorv2si3 = CODE_FOR_nothing,
   CODE_FOR_xorv4hi3 = CODE_FOR_nothing,
   CODE_FOR_xorv1di3 = CODE_FOR_nothing,
   CODE_FOR_spe_evfsabs = CODE_FOR_nothing,
   CODE_FOR_spe_evfsadd = CODE_FOR_nothing,
   CODE_FOR_spe_evfscfsf = CODE_FOR_nothing,
   CODE_FOR_spe_evfscfsi = CODE_FOR_nothing,
   CODE_FOR_spe_evfscfuf = CODE_FOR_nothing,
   CODE_FOR_spe_evfscfui = CODE_FOR_nothing,
   CODE_FOR_spe_evfsctsf = CODE_FOR_nothing,
   CODE_FOR_spe_evfsctsi = CODE_FOR_nothing,
   CODE_FOR_spe_evfsctsiz = CODE_FOR_nothing,
   CODE_FOR_spe_evfsctuf = CODE_FOR_nothing,
   CODE_FOR_spe_evfsctui = CODE_FOR_nothing,
   CODE_FOR_spe_evfsctuiz = CODE_FOR_nothing,
   CODE_FOR_spe_evfsdiv = CODE_FOR_nothing,
   CODE_FOR_spe_evfsmul = CODE_FOR_nothing,
   CODE_FOR_spe_evfsnabs = CODE_FOR_nothing,
   CODE_FOR_spe_evfsneg = CODE_FOR_nothing,
   CODE_FOR_spe_evfssub = CODE_FOR_nothing,
   CODE_FOR_spe_evldd = CODE_FOR_nothing,
   CODE_FOR_spe_evlddx = CODE_FOR_nothing,
   CODE_FOR_spe_evldh = CODE_FOR_nothing,
   CODE_FOR_spe_evldhx = CODE_FOR_nothing,
   CODE_FOR_spe_evldw = CODE_FOR_nothing,
   CODE_FOR_spe_evldwx = CODE_FOR_nothing,
   CODE_FOR_spe_evlwhe = CODE_FOR_nothing,
   CODE_FOR_spe_evlwhex = CODE_FOR_nothing,
   CODE_FOR_spe_evlwhos = CODE_FOR_nothing,
   CODE_FOR_spe_evlwhosx = CODE_FOR_nothing,
   CODE_FOR_spe_evlwhou = CODE_FOR_nothing,
   CODE_FOR_spe_evlwhoux = CODE_FOR_nothing,
   CODE_FOR_spe_brinc = CODE_FOR_nothing,
   CODE_FOR_spe_evmhegsmfaa = CODE_FOR_nothing,
   CODE_FOR_spe_evmhegsmfan = CODE_FOR_nothing,
   CODE_FOR_spe_evmhegsmiaa = CODE_FOR_nothing,
   CODE_FOR_spe_evmhegsmian = CODE_FOR_nothing,
   CODE_FOR_spe_evmhegumiaa = CODE_FOR_nothing,
   CODE_FOR_spe_evmhegumian = CODE_FOR_nothing,
   CODE_FOR_spe_evmhesmfaaw = CODE_FOR_nothing,
   CODE_FOR_spe_evmhesmfanw = CODE_FOR_nothing,
   CODE_FOR_spe_evmhesmfa = CODE_FOR_nothing,
   CODE_FOR_spe_evmhesmf = CODE_FOR_nothing,
   CODE_FOR_spe_evmhesmiaaw = CODE_FOR_nothing,
   CODE_FOR_spe_evmhesmianw = CODE_FOR_nothing,
   CODE_FOR_spe_evmhesmia = CODE_FOR_nothing,
   CODE_FOR_spe_evmhesmi = CODE_FOR_nothing,
   CODE_FOR_spe_evmhessfaaw = CODE_FOR_nothing,
   CODE_FOR_spe_evmhessfanw = CODE_FOR_nothing,
   CODE_FOR_spe_evmhessfa = CODE_FOR_nothing,
   CODE_FOR_spe_evmhessf = CODE_FOR_nothing,
   CODE_FOR_spe_evmhessiaaw = CODE_FOR_nothing,
   CODE_FOR_spe_evmhessianw = CODE_FOR_nothing,
   CODE_FOR_spe_evmheumiaaw = CODE_FOR_nothing,
   CODE_FOR_spe_evmheumianw = CODE_FOR_nothing,
   CODE_FOR_spe_evmheumia = CODE_FOR_nothing,
   CODE_FOR_spe_evmheumi = CODE_FOR_nothing,
   CODE_FOR_spe_evmheusiaaw = CODE_FOR_nothing,
   CODE_FOR_spe_evmheusianw = CODE_FOR_nothing,
   CODE_FOR_spe_evmhogsmfaa = CODE_FOR_nothing,
   CODE_FOR_spe_evmhogsmfan = CODE_FOR_nothing,
   CODE_FOR_spe_evmhogsmiaa = CODE_FOR_nothing,
   CODE_FOR_spe_evmhogsmian = CODE_FOR_nothing,
   CODE_FOR_spe_evmhogumiaa = CODE_FOR_nothing,
   CODE_FOR_spe_evmhogumian = CODE_FOR_nothing,
   CODE_FOR_spe_evmhosmfaaw = CODE_FOR_nothing,
   CODE_FOR_spe_evmhosmfanw = CODE_FOR_nothing,
   CODE_FOR_spe_evmhosmfa = CODE_FOR_nothing,
   CODE_FOR_spe_evmhosmf = CODE_FOR_nothing,
   CODE_FOR_spe_evmhosmiaaw = CODE_FOR_nothing,
   CODE_FOR_spe_evmhosmianw = CODE_FOR_nothing,
   CODE_FOR_spe_evmhosmia = CODE_FOR_nothing,
   CODE_FOR_spe_evmhosmi = CODE_FOR_nothing,
   CODE_FOR_spe_evmhossfaaw = CODE_FOR_nothing,
   CODE_FOR_spe_evmhossfanw = CODE_FOR_nothing,
   CODE_FOR_spe_evmhossfa = CODE_FOR_nothing,
   CODE_FOR_spe_evmhossf = CODE_FOR_nothing,
   CODE_FOR_spe_evmhossiaaw = CODE_FOR_nothing,
   CODE_FOR_spe_evmhossianw = CODE_FOR_nothing,
   CODE_FOR_spe_evmhoumiaaw = CODE_FOR_nothing,
   CODE_FOR_spe_evmhoumianw = CODE_FOR_nothing,
   CODE_FOR_spe_evmhoumia = CODE_FOR_nothing,
   CODE_FOR_spe_evmhoumi = CODE_FOR_nothing,
   CODE_FOR_spe_evmhousiaaw = CODE_FOR_nothing,
   CODE_FOR_spe_evmhousianw = CODE_FOR_nothing,
   CODE_FOR_spe_evmmlssfa = CODE_FOR_nothing,
   CODE_FOR_spe_evmmlssf = CODE_FOR_nothing,
   CODE_FOR_spe_evmwhsmfa = CODE_FOR_nothing,
   CODE_FOR_spe_evmwhsmf = CODE_FOR_nothing,
   CODE_FOR_spe_evmwhsmia = CODE_FOR_nothing,
   CODE_FOR_spe_evmwhsmi = CODE_FOR_nothing,
   CODE_FOR_spe_evmwhssfa = CODE_FOR_nothing,
   CODE_FOR_spe_evmwhusian = CODE_FOR_nothing,
   CODE_FOR_spe_evmwhssf = CODE_FOR_nothing,
   CODE_FOR_spe_evmwhumia = CODE_FOR_nothing,
   CODE_FOR_spe_evmwhumi = CODE_FOR_nothing,
   CODE_FOR_spe_evmwlsmiaaw = CODE_FOR_nothing,
   CODE_FOR_spe_evmwlsmianw = CODE_FOR_nothing,
   CODE_FOR_spe_evmwlssiaaw = CODE_FOR_nothing,
   CODE_FOR_spe_evmwlssianw = CODE_FOR_nothing,
   CODE_FOR_spe_evmwlumiaaw = CODE_FOR_nothing,
   CODE_FOR_spe_evmwlumianw = CODE_FOR_nothing,
   CODE_FOR_spe_evmwlumia = CODE_FOR_nothing,
   CODE_FOR_spe_evmwlumi = CODE_FOR_nothing,
   CODE_FOR_spe_evmwlusiaaw = CODE_FOR_nothing,
   CODE_FOR_spe_evmwlusianw = CODE_FOR_nothing,
   CODE_FOR_spe_evmwsmfaa = CODE_FOR_nothing,
   CODE_FOR_spe_evmwsmfan = CODE_FOR_nothing,
   CODE_FOR_spe_evmwsmfa = CODE_FOR_nothing,
   CODE_FOR_spe_evmwsmf = CODE_FOR_nothing,
   CODE_FOR_spe_evmwsmiaa = CODE_FOR_nothing,
   CODE_FOR_spe_evmwsmian = CODE_FOR_nothing,
   CODE_FOR_spe_evmwsmia = CODE_FOR_nothing,
   CODE_FOR_spe_evmwsmi = CODE_FOR_nothing,
   CODE_FOR_spe_evmwssfaa = CODE_FOR_nothing,
   CODE_FOR_spe_evmwssfan = CODE_FOR_nothing,
   CODE_FOR_spe_evmwssfa = CODE_FOR_nothing,
   CODE_FOR_spe_evmwssf = CODE_FOR_nothing,
   CODE_FOR_spe_evmwumiaa = CODE_FOR_nothing,
   CODE_FOR_spe_evmwumian = CODE_FOR_nothing,
   CODE_FOR_spe_evmwumia = CODE_FOR_nothing,
   CODE_FOR_spe_evmwumi = CODE_FOR_nothing,
   CODE_FOR_addv2si3 = CODE_FOR_nothing,
   CODE_FOR_spe_evaddusiaaw = CODE_FOR_nothing,
   CODE_FOR_spe_evaddumiaaw = CODE_FOR_nothing,
   CODE_FOR_spe_evaddssiaaw = CODE_FOR_nothing,
   CODE_FOR_spe_evaddsmiaaw = CODE_FOR_nothing,
   CODE_FOR_spe_evaddiw = CODE_FOR_nothing,
   CODE_FOR_spe_evsubifw = CODE_FOR_nothing,
   CODE_FOR_subv2si3 = CODE_FOR_nothing,
   CODE_FOR_spe_evsubfusiaaw = CODE_FOR_nothing,
   CODE_FOR_spe_evsubfumiaaw = CODE_FOR_nothing,
   CODE_FOR_spe_evsubfssiaaw = CODE_FOR_nothing,
   CODE_FOR_spe_evsubfsmiaaw = CODE_FOR_nothing,
   CODE_FOR_spe_evmra = CODE_FOR_nothing,
   CODE_FOR_divv2si3 = CODE_FOR_nothing,
   CODE_FOR_spe_evdivwu = CODE_FOR_nothing,
   CODE_FOR_spe_evsplatfi = CODE_FOR_nothing,
   CODE_FOR_spe_evsplati = CODE_FOR_nothing,
   CODE_FOR_spe_evstdd = CODE_FOR_nothing,
   CODE_FOR_spe_evstddx = CODE_FOR_nothing,
   CODE_FOR_spe_evstdh = CODE_FOR_nothing,
   CODE_FOR_spe_evstdhx = CODE_FOR_nothing,
   CODE_FOR_spe_evstdw = CODE_FOR_nothing,
   CODE_FOR_spe_evstdwx = CODE_FOR_nothing,
   CODE_FOR_spe_evstwhe = CODE_FOR_nothing,
   CODE_FOR_spe_evstwhex = CODE_FOR_nothing,
   CODE_FOR_spe_evstwho = CODE_FOR_nothing,
   CODE_FOR_spe_evstwhox = CODE_FOR_nothing,
   CODE_FOR_spe_evstwwe = CODE_FOR_nothing,
   CODE_FOR_spe_evstwwex = CODE_FOR_nothing,
   CODE_FOR_spe_evstwwo = CODE_FOR_nothing,
   CODE_FOR_spe_evstwwox = CODE_FOR_nothing,
   CODE_FOR_mov_sidf_e500_subreg0_be = CODE_FOR_nothing,
   CODE_FOR_mov_siv4hi_e500_subreg0_be = CODE_FOR_nothing,
   CODE_FOR_mov_siv2sf_e500_subreg0_be = CODE_FOR_nothing,
   CODE_FOR_mov_siv1di_e500_subreg0_be = CODE_FOR_nothing,
   CODE_FOR_mov_siv2si_e500_subreg0_be = CODE_FOR_nothing,
   CODE_FOR_mov_sitf_e500_subreg0_be = CODE_FOR_nothing,
   CODE_FOR_mov_sidf_e500_subreg4_le = CODE_FOR_nothing,
   CODE_FOR_mov_siv4hi_e500_subreg4_le = CODE_FOR_nothing,
   CODE_FOR_mov_siv2sf_e500_subreg4_le = CODE_FOR_nothing,
   CODE_FOR_mov_siv1di_e500_subreg4_le = CODE_FOR_nothing,
   CODE_FOR_mov_siv2si_e500_subreg4_le = CODE_FOR_nothing,
   CODE_FOR_mov_sitf_e500_subreg4_le = CODE_FOR_nothing,
   CODE_FOR_spe_truncdfsf2 = CODE_FOR_nothing,
   CODE_FOR_spe_absdf2 = CODE_FOR_nothing,
   CODE_FOR_spe_nabsdf2 = CODE_FOR_nothing,
   CODE_FOR_spe_negdf2 = CODE_FOR_nothing,
   CODE_FOR_spe_adddf3 = CODE_FOR_nothing,
   CODE_FOR_spe_subdf3 = CODE_FOR_nothing,
   CODE_FOR_spe_muldf3 = CODE_FOR_nothing,
   CODE_FOR_spe_divdf3 = CODE_FOR_nothing,
   CODE_FOR_spe_trunctfdf2_internal1 = CODE_FOR_nothing,
   CODE_FOR_spe_trunctfsf2 = CODE_FOR_nothing,
   CODE_FOR_spe_extenddftf2 = CODE_FOR_nothing,
   CODE_FOR_spe_fix_trunctfsi2_internal = CODE_FOR_nothing,
   CODE_FOR_spe_negtf2_internal = CODE_FOR_nothing,
   CODE_FOR_spe_evmwhssfaa = CODE_FOR_nothing,
   CODE_FOR_spe_evmwhssmaa = CODE_FOR_nothing,
   CODE_FOR_spe_evmwhsmfaa = CODE_FOR_nothing,
   CODE_FOR_spe_evmwhsmiaa = CODE_FOR_nothing,
   CODE_FOR_spe_evmwhusiaa = CODE_FOR_nothing,
   CODE_FOR_spe_evmwhumiaa = CODE_FOR_nothing,
   CODE_FOR_spe_evmwhssfan = CODE_FOR_nothing,
   CODE_FOR_spe_evmwhssian = CODE_FOR_nothing,
   CODE_FOR_spe_evmwhsmfan = CODE_FOR_nothing,
   CODE_FOR_spe_evmwhsmian = CODE_FOR_nothing,
   CODE_FOR_spe_evmwhumian = CODE_FOR_nothing,
   CODE_FOR_spe_evmwhgssfaa = CODE_FOR_nothing,
   CODE_FOR_spe_evmwhgsmfaa = CODE_FOR_nothing,
   CODE_FOR_spe_evmwhgsmiaa = CODE_FOR_nothing,
   CODE_FOR_spe_evmwhgumiaa = CODE_FOR_nothing,
   CODE_FOR_spe_evmwhgssfan = CODE_FOR_nothing,
   CODE_FOR_spe_evmwhgsmfan = CODE_FOR_nothing,
   CODE_FOR_spe_evmwhgsmian = CODE_FOR_nothing,
   CODE_FOR_spe_evmwhgumian = CODE_FOR_nothing,
   CODE_FOR_spe_mtspefscr = CODE_FOR_nothing,
   CODE_FOR_spe_mfspefscr = CODE_FOR_nothing,
   CODE_FOR_e500_flip_gt_bit = CODE_FOR_nothing,
   CODE_FOR_cmpsfeq_gpr = CODE_FOR_nothing,
   CODE_FOR_tstsfeq_gpr = CODE_FOR_nothing,
   CODE_FOR_cmpsfgt_gpr = CODE_FOR_nothing,
   CODE_FOR_tstsfgt_gpr = CODE_FOR_nothing,
   CODE_FOR_cmpsflt_gpr = CODE_FOR_nothing,
   CODE_FOR_tstsflt_gpr = CODE_FOR_nothing,
   CODE_FOR_cmpdfeq_gpr = CODE_FOR_nothing,
   CODE_FOR_tstdfeq_gpr = CODE_FOR_nothing,
   CODE_FOR_cmpdfgt_gpr = CODE_FOR_nothing,
   CODE_FOR_tstdfgt_gpr = CODE_FOR_nothing,
   CODE_FOR_cmpdflt_gpr = CODE_FOR_nothing,
   CODE_FOR_tstdflt_gpr = CODE_FOR_nothing,
   CODE_FOR_cmptfeq_gpr = CODE_FOR_nothing,
   CODE_FOR_tsttfeq_gpr = CODE_FOR_nothing,
   CODE_FOR_cmptfgt_gpr = CODE_FOR_nothing,
   CODE_FOR_tsttfgt_gpr = CODE_FOR_nothing,
   CODE_FOR_cmptflt_gpr = CODE_FOR_nothing,
   CODE_FOR_tsttflt_gpr = CODE_FOR_nothing,
   CODE_FOR_e500_cr_ior_compare = CODE_FOR_nothing,
  CODE_FOR_movsd_store = 1950,
  CODE_FOR_movsd_load = 1951,
  CODE_FOR_extendsddd2 = 1952,
  CODE_FOR_truncddsd2 = 1953,
  CODE_FOR_extendddtd2 = 1960,
  CODE_FOR_trunctddd2 = 1961,
  CODE_FOR_adddd3 = 1962,
  CODE_FOR_addtd3 = 1963,
  CODE_FOR_subdd3 = 1964,
  CODE_FOR_subtd3 = 1965,
  CODE_FOR_muldd3 = 1966,
  CODE_FOR_multd3 = 1967,
  CODE_FOR_divdd3 = 1968,
  CODE_FOR_divtd3 = 1969,
  CODE_FOR_floatdidd2 = 1972,
  CODE_FOR_floatditd2 = 1973,
  CODE_FOR_ftruncdd2 = 1974,
  CODE_FOR_fixdddi2 = 1975,
  CODE_FOR_ftrunctd2 = 1976,
  CODE_FOR_fixtddi2 = 1977,
  CODE_FOR_dfp_ddedpd_dd = 1978,
  CODE_FOR_dfp_ddedpd_td = 1979,
  CODE_FOR_dfp_denbcd_dd = 1980,
  CODE_FOR_dfp_denbcd_td = 1981,
  CODE_FOR_dfp_dxex_dd = 1982,
  CODE_FOR_dfp_dxex_td = 1983,
  CODE_FOR_dfp_diex_dd = 1984,
  CODE_FOR_dfp_diex_td = 1985,
  CODE_FOR_dfp_dscli_dd = 1988,
  CODE_FOR_dfp_dscli_td = 1989,
  CODE_FOR_dfp_dscri_dd = 1990,
  CODE_FOR_dfp_dscri_td = 1991,
   CODE_FOR_paired_negv2sf2 = CODE_FOR_nothing,
   CODE_FOR_sqrtv2sf2 = CODE_FOR_nothing,
   CODE_FOR_paired_absv2sf2 = CODE_FOR_nothing,
   CODE_FOR_nabsv2sf2 = CODE_FOR_nothing,
   CODE_FOR_paired_addv2sf3 = CODE_FOR_nothing,
   CODE_FOR_paired_subv2sf3 = CODE_FOR_nothing,
   CODE_FOR_paired_mulv2sf3 = CODE_FOR_nothing,
   CODE_FOR_resv2sf2 = CODE_FOR_nothing,
   CODE_FOR_paired_divv2sf3 = CODE_FOR_nothing,
   CODE_FOR_paired_madds0 = CODE_FOR_nothing,
   CODE_FOR_paired_madds1 = CODE_FOR_nothing,
   CODE_FOR_selv2sf4 = CODE_FOR_nothing,
   CODE_FOR_paired_stx = CODE_FOR_nothing,
   CODE_FOR_paired_lx = CODE_FOR_nothing,
   CODE_FOR_paired_cmpu0 = CODE_FOR_nothing,
   CODE_FOR_paired_cmpu1 = CODE_FOR_nothing,
   CODE_FOR_paired_merge00 = CODE_FOR_nothing,
   CODE_FOR_paired_merge01 = CODE_FOR_nothing,
   CODE_FOR_paired_merge10 = CODE_FOR_nothing,
   CODE_FOR_paired_merge11 = CODE_FOR_nothing,
   CODE_FOR_paired_sum0 = CODE_FOR_nothing,
   CODE_FOR_paired_sum1 = CODE_FOR_nothing,
   CODE_FOR_paired_muls0 = CODE_FOR_nothing,
   CODE_FOR_paired_muls1 = CODE_FOR_nothing,
  CODE_FOR_crypto_vcipher = 1992,
  CODE_FOR_crypto_vncipher = 1993,
  CODE_FOR_crypto_vcipherlast = 1994,
  CODE_FOR_crypto_vncipherlast = 1995,
  CODE_FOR_crypto_vpmsumb = 1996,
  CODE_FOR_crypto_vpmsumh = 1997,
  CODE_FOR_crypto_vpmsumw = 1998,
  CODE_FOR_crypto_vpmsumd = 1999,
  CODE_FOR_crypto_vpermxor_v16qi = 2000,
  CODE_FOR_crypto_vpermxor_v8hi = 2001,
  CODE_FOR_crypto_vpermxor_v4si = 2002,
  CODE_FOR_crypto_vpermxor_v2di = 2003,
  CODE_FOR_crypto_vsbox = 2004,
  CODE_FOR_crypto_vshasigmaw = 2005,
  CODE_FOR_crypto_vshasigmad = 2006,
  CODE_FOR_htm_mfspr_si = 2019,
  CODE_FOR_htm_mfspr_di = 2020,
  CODE_FOR_htm_mtspr_si = 2021,
  CODE_FOR_htm_mtspr_di = 2022,
   CODE_FOR_macho_high = CODE_FOR_nothing,
   CODE_FOR_macho_low = CODE_FOR_nothing,
  CODE_FOR_load_macho_picbase = 2023,
  CODE_FOR_macho_correct_pic = 2024,
  CODE_FOR_reload_macho_picbase = 2025,
  CODE_FOR_extendhisi2 = 2026,
  CODE_FOR_extendhidi2 = 2027,
  CODE_FOR_strlensi = 2028,
  CODE_FOR_addsi3 = 2029,
  CODE_FOR_adddi3 = 2030,
  CODE_FOR_addsi3_carry_in = 2031,
  CODE_FOR_adddi3_carry_in = 2032,
  CODE_FOR_one_cmplsi2 = 2033,
  CODE_FOR_one_cmpldi2 = 2034,
  CODE_FOR_subsi3 = 2035,
  CODE_FOR_subdi3 = 2036,
  CODE_FOR_subfsi3_carry_in = 2037,
  CODE_FOR_subfdi3_carry_in = 2038,
  CODE_FOR_ctzsi2 = 2039,
  CODE_FOR_ctzdi2 = 2040,
  CODE_FOR_ffssi2 = 2041,
  CODE_FOR_ffsdi2 = 2042,
  CODE_FOR_popcountsi2 = 2043,
  CODE_FOR_popcountdi2 = 2044,
  CODE_FOR_paritysi2 = 2045,
  CODE_FOR_paritydi2 = 2046,
  CODE_FOR_bswaphi2 = 2047,
  CODE_FOR_bswapsi2 = 2048,
  CODE_FOR_bswapdi2 = 2049,
  CODE_FOR_smulsi3_highpart = 2050,
  CODE_FOR_umulsi3_highpart = 2051,
  CODE_FOR_smuldi3_highpart = 2052,
  CODE_FOR_umuldi3_highpart = 2053,
  CODE_FOR_mulsidi3 = 2054,
  CODE_FOR_umulsidi3 = 2055,
  CODE_FOR_mulditi3 = 2056,
  CODE_FOR_umulditi3 = 2057,
  CODE_FOR_divsi3 = 2058,
  CODE_FOR_divdi3 = 2059,
  CODE_FOR_modsi3 = 2060,
  CODE_FOR_moddi3 = 2061,
  CODE_FOR_andsi3 = 2062,
  CODE_FOR_anddi3 = 2063,
  CODE_FOR_iorsi3 = 2064,
  CODE_FOR_xorsi3 = 2065,
  CODE_FOR_iordi3 = 2066,
  CODE_FOR_xordi3 = 2067,
  CODE_FOR_recipsf3 = 2068,
  CODE_FOR_recipdf3 = 2069,
  CODE_FOR_recipv4sf3 = 2070,
  CODE_FOR_recipv2df3 = 2071,
  CODE_FOR_rsqrtsf2 = 2072,
  CODE_FOR_rsqrtdf2 = 2073,
  CODE_FOR_rsqrtv4sf2 = 2074,
  CODE_FOR_rsqrtv2df2 = 2075,
  CODE_FOR_abssf2 = 2076,
  CODE_FOR_absdf2 = 2077,
  CODE_FOR_negsf2 = 2078,
  CODE_FOR_negdf2 = 2079,
  CODE_FOR_addsf3 = 2080,
  CODE_FOR_adddf3 = 2081,
  CODE_FOR_subsf3 = 2082,
  CODE_FOR_subdf3 = 2083,
  CODE_FOR_mulsf3 = 2084,
  CODE_FOR_muldf3 = 2085,
  CODE_FOR_divsf3 = 2086,
  CODE_FOR_divdf3 = 2087,
  CODE_FOR_sqrtsf2 = 2088,
  CODE_FOR_sqrtdf2 = 2089,
  CODE_FOR_extendsfdf2 = 2090,
  CODE_FOR_truncdfsf2 = 2091,
  CODE_FOR_signbitkf2 = 2092,
  CODE_FOR_signbitif2 = 2093,
  CODE_FOR_signbittf2 = 2094,
  CODE_FOR_copysignsf3 = 2095,
  CODE_FOR_copysigndf3 = 2096,
  CODE_FOR_sminsf3 = 2097,
  CODE_FOR_smaxsf3 = 2098,
  CODE_FOR_smindf3 = 2099,
  CODE_FOR_smaxdf3 = 2100,
  CODE_FOR_movsicc = 2101,
  CODE_FOR_movdicc = 2102,
  CODE_FOR_movsfcc = 2103,
  CODE_FOR_movdfcc = 2104,
  CODE_FOR_floatsidf2 = 2105,
  CODE_FOR_floatunssisf2 = 2106,
  CODE_FOR_floatunssidf2 = 2107,
  CODE_FOR_floatqisf2 = 2108,
  CODE_FOR_floatqidf2 = 2109,
  CODE_FOR_floathisf2 = 2110,
  CODE_FOR_floathidf2 = 2111,
  CODE_FOR_floatunsqisf2 = 2112,
  CODE_FOR_floatunsqidf2 = 2113,
  CODE_FOR_floatunshisf2 = 2114,
  CODE_FOR_floatunshidf2 = 2115,
  CODE_FOR_fix_truncsfsi2 = 2116,
  CODE_FOR_fix_truncdfsi2 = 2117,
  CODE_FOR_fix_truncsfdi2 = 2118,
  CODE_FOR_fix_truncdfdi2 = 2119,
  CODE_FOR_fix_truncsfqi2 = 2120,
  CODE_FOR_fix_truncsfhi2 = 2121,
  CODE_FOR_fix_truncdfqi2 = 2122,
  CODE_FOR_fix_truncdfhi2 = 2123,
  CODE_FOR_fixuns_truncsfsi2 = 2124,
  CODE_FOR_fixuns_truncdfsi2 = 2125,
  CODE_FOR_fixuns_truncsfqi2 = 2126,
  CODE_FOR_fixuns_truncsfhi2 = 2127,
  CODE_FOR_fixuns_truncdfqi2 = 2128,
  CODE_FOR_fixuns_truncdfhi2 = 2129,
  CODE_FOR_lroundsfdi2 = 2130,
  CODE_FOR_lrounddfdi2 = 2131,
  CODE_FOR_floatsisf2 = 2132,
  CODE_FOR_floatdidf2 = 2133,
  CODE_FOR_floatunsdidf2 = 2134,
  CODE_FOR_floatdisf2 = 2135,
  CODE_FOR_floatdisf2_internal2 = 2136,
  CODE_FOR_floatunsdisf2 = 2137,
  CODE_FOR_addti3 = 2138,
  CODE_FOR_subti3 = 2139,
  CODE_FOR_andti3 = 2140,
  CODE_FOR_andpti3 = 2141,
  CODE_FOR_andv16qi3 = 2142,
  CODE_FOR_andv8hi3 = 2143,
  CODE_FOR_andv4si3 = 2144,
  CODE_FOR_andv4sf3 = 2145,
  CODE_FOR_andv2di3 = 2146,
  CODE_FOR_andv2df3 = 2147,
  CODE_FOR_andv1ti3 = 2148,
  CODE_FOR_iorti3 = 2149,
  CODE_FOR_iorpti3 = 2150,
  CODE_FOR_iorv16qi3 = 2151,
  CODE_FOR_iorv8hi3 = 2152,
  CODE_FOR_iorv4si3 = 2153,
  CODE_FOR_iorv4sf3 = 2154,
  CODE_FOR_iorv2di3 = 2155,
  CODE_FOR_iorv2df3 = 2156,
  CODE_FOR_iorv1ti3 = 2157,
  CODE_FOR_xorti3 = 2158,
  CODE_FOR_xorpti3 = 2159,
  CODE_FOR_xorv16qi3 = 2160,
  CODE_FOR_xorv8hi3 = 2161,
  CODE_FOR_xorv4si3 = 2162,
  CODE_FOR_xorv4sf3 = 2163,
  CODE_FOR_xorv2di3 = 2164,
  CODE_FOR_xorv2df3 = 2165,
  CODE_FOR_xorv1ti3 = 2166,
  CODE_FOR_one_cmplti2 = 2167,
  CODE_FOR_one_cmplpti2 = 2168,
  CODE_FOR_one_cmplv16qi2 = 2169,
  CODE_FOR_one_cmplv8hi2 = 2170,
  CODE_FOR_one_cmplv4si2 = 2171,
  CODE_FOR_one_cmplv4sf2 = 2172,
  CODE_FOR_one_cmplv2di2 = 2173,
  CODE_FOR_one_cmplv2df2 = 2174,
  CODE_FOR_one_cmplv1ti2 = 2175,
  CODE_FOR_norti3 = 2176,
  CODE_FOR_norpti3 = 2177,
  CODE_FOR_norv16qi3 = 2178,
  CODE_FOR_norv8hi3 = 2179,
  CODE_FOR_norv4si3 = 2180,
  CODE_FOR_norv4sf3 = 2181,
  CODE_FOR_norv2di3 = 2182,
  CODE_FOR_norv2df3 = 2183,
  CODE_FOR_norv1ti3 = 2184,
  CODE_FOR_andcti3 = 2185,
  CODE_FOR_andcpti3 = 2186,
  CODE_FOR_andcv16qi3 = 2187,
  CODE_FOR_andcv8hi3 = 2188,
  CODE_FOR_andcv4si3 = 2189,
  CODE_FOR_andcv4sf3 = 2190,
  CODE_FOR_andcv2di3 = 2191,
  CODE_FOR_andcv2df3 = 2192,
  CODE_FOR_andcv1ti3 = 2193,
  CODE_FOR_eqvti3 = 2194,
  CODE_FOR_eqvpti3 = 2195,
  CODE_FOR_eqvv16qi3 = 2196,
  CODE_FOR_eqvv8hi3 = 2197,
  CODE_FOR_eqvv4si3 = 2198,
  CODE_FOR_eqvv4sf3 = 2199,
  CODE_FOR_eqvv2di3 = 2200,
  CODE_FOR_eqvv2df3 = 2201,
  CODE_FOR_eqvv1ti3 = 2202,
  CODE_FOR_nandti3 = 2203,
  CODE_FOR_nandpti3 = 2204,
  CODE_FOR_nandv16qi3 = 2205,
  CODE_FOR_nandv8hi3 = 2206,
  CODE_FOR_nandv4si3 = 2207,
  CODE_FOR_nandv4sf3 = 2208,
  CODE_FOR_nandv2di3 = 2209,
  CODE_FOR_nandv2df3 = 2210,
  CODE_FOR_nandv1ti3 = 2211,
  CODE_FOR_orcti3 = 2212,
  CODE_FOR_orcpti3 = 2213,
  CODE_FOR_orcv16qi3 = 2214,
  CODE_FOR_orcv8hi3 = 2215,
  CODE_FOR_orcv4si3 = 2216,
  CODE_FOR_orcv4sf3 = 2217,
  CODE_FOR_orcv2di3 = 2218,
  CODE_FOR_orcv2df3 = 2219,
  CODE_FOR_orcv1ti3 = 2220,
  CODE_FOR_movsi_got = 2221,
  CODE_FOR_movqi = 2222,
  CODE_FOR_movhi = 2223,
  CODE_FOR_movsi = 2224,
  CODE_FOR_movdi = 2225,
  CODE_FOR_movti = 2226,
  CODE_FOR_movpti = 2227,
  CODE_FOR_movcc = 2228,
  CODE_FOR_movsf = 2229,
  CODE_FOR_movsd = 2230,
  CODE_FOR_movdf = 2231,
  CODE_FOR_movdd = 2232,
  CODE_FOR_movtf = 2233,
  CODE_FOR_movif = 2234,
  CODE_FOR_movtd = 2235,
  CODE_FOR_extenddfkf2 = 2236,
  CODE_FOR_extenddfif2 = 2237,
  CODE_FOR_extenddftf2 = 2238,
  CODE_FOR_extendsfkf2 = 2239,
  CODE_FOR_extendsfif2 = 2240,
  CODE_FOR_extendsftf2 = 2241,
  CODE_FOR_trunckfdf2 = 2242,
  CODE_FOR_truncifdf2 = 2243,
  CODE_FOR_trunctfdf2 = 2244,
  CODE_FOR_trunckfsf2 = 2245,
  CODE_FOR_truncifsf2 = 2246,
  CODE_FOR_trunctfsf2 = 2247,
  CODE_FOR_floatsikf2 = 2248,
  CODE_FOR_floatsiif2 = 2249,
  CODE_FOR_floatsitf2 = 2250,
  CODE_FOR_fix_trunckfsi2 = 2251,
  CODE_FOR_fix_truncifsi2 = 2252,
  CODE_FOR_fix_trunctfsi2 = 2253,
  CODE_FOR_fix_truncifsi2_fprs = 2254,
  CODE_FOR_fix_trunctfsi2_fprs = 2255,
  CODE_FOR_fix_trunckfdi2 = 2256,
  CODE_FOR_fix_trunctfdi2 = 2257,
  CODE_FOR_fixuns_trunckfsi2 = 2258,
  CODE_FOR_fixuns_trunctfsi2 = 2259,
  CODE_FOR_fixuns_trunckfdi2 = 2260,
  CODE_FOR_fixuns_trunctfdi2 = 2261,
  CODE_FOR_floatdikf2 = 2262,
  CODE_FOR_floatditf2 = 2263,
  CODE_FOR_floatunsdikf2 = 2264,
  CODE_FOR_floatunsditf2 = 2265,
  CODE_FOR_floatunskf2 = 2266,
  CODE_FOR_floatunstf2 = 2267,
  CODE_FOR_negkf2 = 2268,
  CODE_FOR_negif2 = 2269,
  CODE_FOR_negtf2 = 2270,
  CODE_FOR_abskf2 = 2271,
  CODE_FOR_absif2 = 2272,
  CODE_FOR_abstf2 = 2273,
  CODE_FOR_absif2_internal = 2274,
  CODE_FOR_abstf2_internal = 2275,
  CODE_FOR_ieee_128bit_negative_zero = 2276,
  CODE_FOR_extendiftf2 = 2277,
  CODE_FOR_extendifkf2 = 2278,
  CODE_FOR_extendtfkf2 = 2279,
  CODE_FOR_trunciftf2 = 2280,
  CODE_FOR_truncifkf2 = 2281,
  CODE_FOR_trunckftf2 = 2282,
  CODE_FOR_trunctfif2 = 2283,
  CODE_FOR_reload_si_store = 2284,
  CODE_FOR_reload_di_store = 2285,
  CODE_FOR_reload_si_load = 2286,
  CODE_FOR_reload_di_load = 2287,
  CODE_FOR_reload_v16qi_si_store = 2288,
  CODE_FOR_reload_v8hi_si_store = 2289,
  CODE_FOR_reload_v4si_si_store = 2290,
  CODE_FOR_reload_v2di_si_store = 2291,
  CODE_FOR_reload_v4sf_si_store = 2292,
  CODE_FOR_reload_v2df_si_store = 2293,
  CODE_FOR_reload_v1ti_si_store = 2294,
  CODE_FOR_reload_sf_si_store = 2295,
  CODE_FOR_reload_sd_si_store = 2296,
  CODE_FOR_reload_si_si_store = 2297,
  CODE_FOR_reload_df_si_store = 2298,
  CODE_FOR_reload_dd_si_store = 2299,
  CODE_FOR_reload_di_si_store = 2300,
  CODE_FOR_reload_ti_si_store = 2301,
  CODE_FOR_reload_pti_si_store = 2302,
  CODE_FOR_reload_kf_si_store = 2303,
  CODE_FOR_reload_if_si_store = 2304,
  CODE_FOR_reload_tf_si_store = 2305,
  CODE_FOR_reload_v16qi_di_store = 2306,
  CODE_FOR_reload_v8hi_di_store = 2307,
  CODE_FOR_reload_v4si_di_store = 2308,
  CODE_FOR_reload_v2di_di_store = 2309,
  CODE_FOR_reload_v4sf_di_store = 2310,
  CODE_FOR_reload_v2df_di_store = 2311,
  CODE_FOR_reload_v1ti_di_store = 2312,
  CODE_FOR_reload_sf_di_store = 2313,
  CODE_FOR_reload_sd_di_store = 2314,
  CODE_FOR_reload_si_di_store = 2315,
  CODE_FOR_reload_df_di_store = 2316,
  CODE_FOR_reload_dd_di_store = 2317,
  CODE_FOR_reload_di_di_store = 2318,
  CODE_FOR_reload_ti_di_store = 2319,
  CODE_FOR_reload_pti_di_store = 2320,
  CODE_FOR_reload_kf_di_store = 2321,
  CODE_FOR_reload_if_di_store = 2322,
  CODE_FOR_reload_tf_di_store = 2323,
  CODE_FOR_reload_v16qi_si_load = 2324,
  CODE_FOR_reload_v8hi_si_load = 2325,
  CODE_FOR_reload_v4si_si_load = 2326,
  CODE_FOR_reload_v2di_si_load = 2327,
  CODE_FOR_reload_v4sf_si_load = 2328,
  CODE_FOR_reload_v2df_si_load = 2329,
  CODE_FOR_reload_v1ti_si_load = 2330,
  CODE_FOR_reload_sf_si_load = 2331,
  CODE_FOR_reload_sd_si_load = 2332,
  CODE_FOR_reload_si_si_load = 2333,
  CODE_FOR_reload_df_si_load = 2334,
  CODE_FOR_reload_dd_si_load = 2335,
  CODE_FOR_reload_di_si_load = 2336,
  CODE_FOR_reload_ti_si_load = 2337,
  CODE_FOR_reload_pti_si_load = 2338,
  CODE_FOR_reload_kf_si_load = 2339,
  CODE_FOR_reload_if_si_load = 2340,
  CODE_FOR_reload_tf_si_load = 2341,
  CODE_FOR_reload_v16qi_di_load = 2342,
  CODE_FOR_reload_v8hi_di_load = 2343,
  CODE_FOR_reload_v4si_di_load = 2344,
  CODE_FOR_reload_v2di_di_load = 2345,
  CODE_FOR_reload_v4sf_di_load = 2346,
  CODE_FOR_reload_v2df_di_load = 2347,
  CODE_FOR_reload_v1ti_di_load = 2348,
  CODE_FOR_reload_sf_di_load = 2349,
  CODE_FOR_reload_sd_di_load = 2350,
  CODE_FOR_reload_si_di_load = 2351,
  CODE_FOR_reload_df_di_load = 2352,
  CODE_FOR_reload_dd_di_load = 2353,
  CODE_FOR_reload_di_di_load = 2354,
  CODE_FOR_reload_ti_di_load = 2355,
  CODE_FOR_reload_pti_di_load = 2356,
  CODE_FOR_reload_kf_di_load = 2357,
  CODE_FOR_reload_if_di_load = 2358,
  CODE_FOR_reload_tf_di_load = 2359,
  CODE_FOR_load_multiple = 2360,
  CODE_FOR_store_multiple = 2361,
  CODE_FOR_setmemsi = 2362,
  CODE_FOR_cmpstrnsi = 2363,
  CODE_FOR_cmpstrsi = 2364,
  CODE_FOR_cmpmemsi = 2365,
  CODE_FOR_movmemsi = 2366,
  CODE_FOR_movmemsi_8reg = 2367,
  CODE_FOR_movmemsi_6reg = 2368,
  CODE_FOR_movmemsi_4reg = 2369,
  CODE_FOR_movmemsi_2reg = 2370,
  CODE_FOR_movmemsi_1reg = 2371,
   CODE_FOR_tls_get_tpointer = CODE_FOR_nothing,
   CODE_FOR_tls_get_addrsi = CODE_FOR_nothing,
   CODE_FOR_tls_get_addrdi = CODE_FOR_nothing,
  CODE_FOR_allocate_stack = 2372,
  CODE_FOR_save_stack_function = 2373,
  CODE_FOR_restore_stack_function = 2374,
  CODE_FOR_restore_stack_block = 2375,
  CODE_FOR_save_stack_nonlocal = 2376,
  CODE_FOR_restore_stack_nonlocal = 2377,
  CODE_FOR_load_toc_v4_PIC_1 = 2378,
  CODE_FOR_load_toc_v4_PIC_1b = 2379,
  CODE_FOR_builtin_setjmp_receiver = 2380,
  CODE_FOR_call = 2381,
  CODE_FOR_call_value = 2382,
  CODE_FOR_untyped_call = 2383,
  CODE_FOR_sibcall = 2384,
  CODE_FOR_sibcall_value = 2385,
  CODE_FOR_sibcall_epilogue = 2386,
  CODE_FOR_probe_stack_address = 2387,
  CODE_FOR_cbranchsi4 = 2388,
  CODE_FOR_cbranchdi4 = 2389,
  CODE_FOR_cbranchsf4 = 2390,
  CODE_FOR_cbranchdf4 = 2391,
  CODE_FOR_cbranchtf4 = 2392,
  CODE_FOR_cbranchif4 = 2393,
  CODE_FOR_cbranchkf4 = 2394,
  CODE_FOR_cbranchdd4 = 2395,
  CODE_FOR_cbranchtd4 = 2396,
  CODE_FOR_cstoresi4_signed = 2397,
  CODE_FOR_cstoredi4_signed = 2398,
  CODE_FOR_cstoresi4_unsigned = 2399,
  CODE_FOR_cstoredi4_unsigned = 2400,
  CODE_FOR_cstore_si_as_di = 2401,
  CODE_FOR_cstoresi4_signed_imm = 2402,
  CODE_FOR_cstoredi4_signed_imm = 2403,
  CODE_FOR_cstoresi4_unsigned_imm = 2404,
  CODE_FOR_cstoredi4_unsigned_imm = 2405,
  CODE_FOR_cstoresi4 = 2406,
  CODE_FOR_cstoredi4 = 2407,
  CODE_FOR_cstoresf4 = 2408,
  CODE_FOR_cstoredf4 = 2409,
  CODE_FOR_cstoretf4 = 2410,
  CODE_FOR_cstoreif4 = 2411,
  CODE_FOR_cstorekf4 = 2412,
  CODE_FOR_cstoredd4 = 2413,
  CODE_FOR_cstoretd4 = 2414,
  CODE_FOR_stack_protect_set = 2415,
  CODE_FOR_stack_protect_test = 2416,
  CODE_FOR_indirect_jump = 2417,
  CODE_FOR_tablejump = 2418,
  CODE_FOR_tablejumpsi = 2419,
  CODE_FOR_tablejumpsi_nospec = 2420,
  CODE_FOR_tablejumpdi = 2421,
  CODE_FOR_tablejumpdi_nospec = 2422,
  CODE_FOR_doloop_end = 2423,
  CODE_FOR_ctrsi = 2424,
  CODE_FOR_ctrdi = 2425,
  CODE_FOR_ctrapsi4 = 2426,
  CODE_FOR_ctrapdi4 = 2427,
  CODE_FOR_prologue = 2428,
  CODE_FOR_epilogue = 2429,
  CODE_FOR_movsi_to_cr_one = 2430,
  CODE_FOR_eh_return = 2431,
  CODE_FOR_split_stack_prologue = 2432,
  CODE_FOR_load_split_stack_limit = 2433,
  CODE_FOR_split_stack_space_check = 2434,
  CODE_FOR_fmasf4 = 2435,
  CODE_FOR_fmadf4 = 2436,
   CODE_FOR_fmav2sf4 = CODE_FOR_nothing,
  CODE_FOR_fmav4sf4 = 2437,
  CODE_FOR_fmav2df4 = 2438,
  CODE_FOR_fmakf4 = 2439,
  CODE_FOR_fmatf4 = 2440,
  CODE_FOR_fmssf4 = 2441,
  CODE_FOR_fmsdf4 = 2442,
   CODE_FOR_fmsv2sf4 = CODE_FOR_nothing,
  CODE_FOR_fmsv4sf4 = 2443,
  CODE_FOR_fmsv2df4 = 2444,
  CODE_FOR_fmskf4 = 2445,
  CODE_FOR_fmstf4 = 2446,
  CODE_FOR_fnmasf4 = 2447,
  CODE_FOR_fnmadf4 = 2448,
  CODE_FOR_fnmav2sf4 = 2449,
  CODE_FOR_fnmav4sf4 = 2450,
  CODE_FOR_fnmav2df4 = 2451,
  CODE_FOR_fnmakf4 = 2452,
  CODE_FOR_fnmatf4 = 2453,
  CODE_FOR_fnmssf4 = 2454,
  CODE_FOR_fnmsdf4 = 2455,
  CODE_FOR_fnmsv2sf4 = 2456,
  CODE_FOR_fnmsv4sf4 = 2457,
  CODE_FOR_fnmsv2df4 = 2458,
  CODE_FOR_fnmskf4 = 2459,
  CODE_FOR_fnmstf4 = 2460,
  CODE_FOR_nfmasf4 = 2461,
  CODE_FOR_nfmadf4 = 2462,
   CODE_FOR_nfmav2sf4 = CODE_FOR_nothing,
  CODE_FOR_nfmav4sf4 = 2463,
  CODE_FOR_nfmav2df4 = 2464,
  CODE_FOR_nfmakf4 = 2465,
  CODE_FOR_nfmatf4 = 2466,
  CODE_FOR_nfmssf4 = 2467,
  CODE_FOR_nfmsdf4 = 2468,
   CODE_FOR_nfmsv2sf4 = CODE_FOR_nothing,
  CODE_FOR_nfmsv4sf4 = 2469,
  CODE_FOR_nfmsv2df4 = 2470,
  CODE_FOR_nfmskf4 = 2471,
  CODE_FOR_nfmstf4 = 2472,
  CODE_FOR_rs6000_get_timebase = 2473,
  CODE_FOR_unpacktf = 2474,
  CODE_FOR_unpackif = 2475,
  CODE_FOR_unpacktd = 2476,
  CODE_FOR_copysignkf3 = 2477,
  CODE_FOR_copysigntf3 = 2478,
  CODE_FOR_mem_thread_fence = 2479,
  CODE_FOR_hwsync = 2480,
  CODE_FOR_lwsync = 2481,
  CODE_FOR_atomic_loadqi = 2482,
  CODE_FOR_atomic_loadhi = 2483,
  CODE_FOR_atomic_loadsi = 2484,
  CODE_FOR_atomic_loaddi = 2485,
  CODE_FOR_atomic_loadti = 2486,
  CODE_FOR_atomic_storeqi = 2487,
  CODE_FOR_atomic_storehi = 2488,
  CODE_FOR_atomic_storesi = 2489,
  CODE_FOR_atomic_storedi = 2490,
  CODE_FOR_atomic_storeti = 2491,
  CODE_FOR_load_lockedti = 2492,
  CODE_FOR_store_conditionalti = 2493,
  CODE_FOR_atomic_compare_and_swapqi = 2494,
  CODE_FOR_atomic_compare_and_swaphi = 2495,
  CODE_FOR_atomic_compare_and_swapsi = 2496,
  CODE_FOR_atomic_compare_and_swapdi = 2497,
  CODE_FOR_atomic_compare_and_swapti = 2498,
  CODE_FOR_atomic_exchangeqi = 2499,
  CODE_FOR_atomic_exchangehi = 2500,
  CODE_FOR_atomic_exchangesi = 2501,
  CODE_FOR_atomic_exchangedi = 2502,
  CODE_FOR_atomic_exchangeti = 2503,
  CODE_FOR_atomic_addqi = 2504,
  CODE_FOR_atomic_subqi = 2505,
  CODE_FOR_atomic_orqi = 2506,
  CODE_FOR_atomic_xorqi = 2507,
  CODE_FOR_atomic_andqi = 2508,
  CODE_FOR_atomic_addhi = 2509,
  CODE_FOR_atomic_subhi = 2510,
  CODE_FOR_atomic_orhi = 2511,
  CODE_FOR_atomic_xorhi = 2512,
  CODE_FOR_atomic_andhi = 2513,
  CODE_FOR_atomic_addsi = 2514,
  CODE_FOR_atomic_subsi = 2515,
  CODE_FOR_atomic_orsi = 2516,
  CODE_FOR_atomic_xorsi = 2517,
  CODE_FOR_atomic_andsi = 2518,
  CODE_FOR_atomic_adddi = 2519,
  CODE_FOR_atomic_subdi = 2520,
  CODE_FOR_atomic_ordi = 2521,
  CODE_FOR_atomic_xordi = 2522,
  CODE_FOR_atomic_anddi = 2523,
  CODE_FOR_atomic_addti = 2524,
  CODE_FOR_atomic_subti = 2525,
  CODE_FOR_atomic_orti = 2526,
  CODE_FOR_atomic_xorti = 2527,
  CODE_FOR_atomic_andti = 2528,
  CODE_FOR_atomic_nandqi = 2529,
  CODE_FOR_atomic_nandhi = 2530,
  CODE_FOR_atomic_nandsi = 2531,
  CODE_FOR_atomic_nanddi = 2532,
  CODE_FOR_atomic_nandti = 2533,
  CODE_FOR_atomic_fetch_addqi = 2534,
  CODE_FOR_atomic_fetch_subqi = 2535,
  CODE_FOR_atomic_fetch_orqi = 2536,
  CODE_FOR_atomic_fetch_xorqi = 2537,
  CODE_FOR_atomic_fetch_andqi = 2538,
  CODE_FOR_atomic_fetch_addhi = 2539,
  CODE_FOR_atomic_fetch_subhi = 2540,
  CODE_FOR_atomic_fetch_orhi = 2541,
  CODE_FOR_atomic_fetch_xorhi = 2542,
  CODE_FOR_atomic_fetch_andhi = 2543,
  CODE_FOR_atomic_fetch_addsi = 2544,
  CODE_FOR_atomic_fetch_subsi = 2545,
  CODE_FOR_atomic_fetch_orsi = 2546,
  CODE_FOR_atomic_fetch_xorsi = 2547,
  CODE_FOR_atomic_fetch_andsi = 2548,
  CODE_FOR_atomic_fetch_adddi = 2549,
  CODE_FOR_atomic_fetch_subdi = 2550,
  CODE_FOR_atomic_fetch_ordi = 2551,
  CODE_FOR_atomic_fetch_xordi = 2552,
  CODE_FOR_atomic_fetch_anddi = 2553,
  CODE_FOR_atomic_fetch_addti = 2554,
  CODE_FOR_atomic_fetch_subti = 2555,
  CODE_FOR_atomic_fetch_orti = 2556,
  CODE_FOR_atomic_fetch_xorti = 2557,
  CODE_FOR_atomic_fetch_andti = 2558,
  CODE_FOR_atomic_fetch_nandqi = 2559,
  CODE_FOR_atomic_fetch_nandhi = 2560,
  CODE_FOR_atomic_fetch_nandsi = 2561,
  CODE_FOR_atomic_fetch_nanddi = 2562,
  CODE_FOR_atomic_fetch_nandti = 2563,
  CODE_FOR_atomic_add_fetchqi = 2564,
  CODE_FOR_atomic_sub_fetchqi = 2565,
  CODE_FOR_atomic_or_fetchqi = 2566,
  CODE_FOR_atomic_xor_fetchqi = 2567,
  CODE_FOR_atomic_and_fetchqi = 2568,
  CODE_FOR_atomic_add_fetchhi = 2569,
  CODE_FOR_atomic_sub_fetchhi = 2570,
  CODE_FOR_atomic_or_fetchhi = 2571,
  CODE_FOR_atomic_xor_fetchhi = 2572,
  CODE_FOR_atomic_and_fetchhi = 2573,
  CODE_FOR_atomic_add_fetchsi = 2574,
  CODE_FOR_atomic_sub_fetchsi = 2575,
  CODE_FOR_atomic_or_fetchsi = 2576,
  CODE_FOR_atomic_xor_fetchsi = 2577,
  CODE_FOR_atomic_and_fetchsi = 2578,
  CODE_FOR_atomic_add_fetchdi = 2579,
  CODE_FOR_atomic_sub_fetchdi = 2580,
  CODE_FOR_atomic_or_fetchdi = 2581,
  CODE_FOR_atomic_xor_fetchdi = 2582,
  CODE_FOR_atomic_and_fetchdi = 2583,
  CODE_FOR_atomic_add_fetchti = 2584,
  CODE_FOR_atomic_sub_fetchti = 2585,
  CODE_FOR_atomic_or_fetchti = 2586,
  CODE_FOR_atomic_xor_fetchti = 2587,
  CODE_FOR_atomic_and_fetchti = 2588,
  CODE_FOR_atomic_nand_fetchqi = 2589,
  CODE_FOR_atomic_nand_fetchhi = 2590,
  CODE_FOR_atomic_nand_fetchsi = 2591,
  CODE_FOR_atomic_nand_fetchdi = 2592,
  CODE_FOR_atomic_nand_fetchti = 2593,
  CODE_FOR_movv16qi = 2594,
  CODE_FOR_movv8hi = 2595,
  CODE_FOR_movv4si = 2596,
  CODE_FOR_movv2di = 2597,
  CODE_FOR_movv4sf = 2598,
  CODE_FOR_movv2df = 2599,
  CODE_FOR_movv1ti = 2600,
  CODE_FOR_movkf = 2601,
  CODE_FOR_vector_load_v16qi = 2602,
  CODE_FOR_vector_load_v8hi = 2603,
  CODE_FOR_vector_load_v4si = 2604,
  CODE_FOR_vector_load_v2di = 2605,
  CODE_FOR_vector_load_v4sf = 2606,
  CODE_FOR_vector_load_v2df = 2607,
  CODE_FOR_vector_load_v1ti = 2608,
  CODE_FOR_vector_load_kf = 2609,
  CODE_FOR_vector_store_v16qi = 2610,
  CODE_FOR_vector_store_v8hi = 2611,
  CODE_FOR_vector_store_v4si = 2612,
  CODE_FOR_vector_store_v2di = 2613,
  CODE_FOR_vector_store_v4sf = 2614,
  CODE_FOR_vector_store_v2df = 2615,
  CODE_FOR_vector_store_v1ti = 2616,
  CODE_FOR_vector_store_kf = 2617,
  CODE_FOR_vector_altivec_load_v16qi = 2618,
  CODE_FOR_vector_altivec_load_v8hi = 2619,
  CODE_FOR_vector_altivec_load_v4si = 2620,
  CODE_FOR_vector_altivec_load_v2di = 2621,
  CODE_FOR_vector_altivec_load_v4sf = 2622,
  CODE_FOR_vector_altivec_load_v2df = 2623,
  CODE_FOR_vector_altivec_load_v1ti = 2624,
  CODE_FOR_vector_altivec_load_kf = 2625,
  CODE_FOR_vector_altivec_store_v16qi = 2626,
  CODE_FOR_vector_altivec_store_v8hi = 2627,
  CODE_FOR_vector_altivec_store_v4si = 2628,
  CODE_FOR_vector_altivec_store_v2di = 2629,
  CODE_FOR_vector_altivec_store_v4sf = 2630,
  CODE_FOR_vector_altivec_store_v2df = 2631,
  CODE_FOR_vector_altivec_store_v1ti = 2632,
  CODE_FOR_vector_altivec_store_kf = 2633,
  CODE_FOR_addv4sf3 = 2634,
  CODE_FOR_addv2df3 = 2635,
  CODE_FOR_subv4sf3 = 2636,
  CODE_FOR_subv2df3 = 2637,
  CODE_FOR_mulv4sf3 = 2638,
  CODE_FOR_mulv2df3 = 2639,
  CODE_FOR_divv4sf3 = 2640,
  CODE_FOR_divv2df3 = 2641,
  CODE_FOR_negv4sf2 = 2642,
  CODE_FOR_negv2df2 = 2643,
  CODE_FOR_absv4sf2 = 2644,
  CODE_FOR_absv2df2 = 2645,
  CODE_FOR_sminv4sf3 = 2646,
  CODE_FOR_sminv2df3 = 2647,
  CODE_FOR_smaxv4sf3 = 2648,
  CODE_FOR_smaxv2df3 = 2649,
  CODE_FOR_sqrtv4sf2 = 2650,
  CODE_FOR_sqrtv2df2 = 2651,
  CODE_FOR_rsqrtev4sf2 = 2652,
  CODE_FOR_rsqrtev2df2 = 2653,
  CODE_FOR_rev4sf2 = 2654,
  CODE_FOR_rev2df2 = 2655,
  CODE_FOR_ftruncv4sf2 = 2656,
  CODE_FOR_ftruncv2df2 = 2657,
  CODE_FOR_vector_ceilv4sf2 = 2658,
  CODE_FOR_vector_ceilv2df2 = 2659,
  CODE_FOR_vector_floorv4sf2 = 2660,
  CODE_FOR_vector_floorv2df2 = 2661,
  CODE_FOR_vector_btruncv4sf2 = 2662,
  CODE_FOR_vector_btruncv2df2 = 2663,
  CODE_FOR_vector_copysignv4sf3 = 2664,
  CODE_FOR_vector_copysignv2df3 = 2665,
  CODE_FOR_vcondv4sfv4sf = 2666,
  CODE_FOR_vcondv2dfv2df = 2667,
  CODE_FOR_vcondv16qiv16qi = 2668,
  CODE_FOR_vcondv8hiv8hi = 2669,
  CODE_FOR_vcondv4siv4si = 2670,
  CODE_FOR_vcondv2div2di = 2671,
  CODE_FOR_vcondv4sfv4si = 2672,
  CODE_FOR_vcondv4siv4sf = 2673,
  CODE_FOR_vconduv16qiv16qi = 2674,
  CODE_FOR_vconduv8hiv8hi = 2675,
  CODE_FOR_vconduv4siv4si = 2676,
  CODE_FOR_vconduv2div2di = 2677,
  CODE_FOR_vconduv4sfv4si = 2678,
  CODE_FOR_vector_eqv16qi = 2679,
  CODE_FOR_vector_eqv8hi = 2680,
  CODE_FOR_vector_eqv4si = 2681,
  CODE_FOR_vector_eqv2di = 2682,
  CODE_FOR_vector_eqv4sf = 2683,
  CODE_FOR_vector_eqv2df = 2684,
  CODE_FOR_vector_gtv16qi = 2685,
  CODE_FOR_vector_gtv8hi = 2686,
  CODE_FOR_vector_gtv4si = 2687,
  CODE_FOR_vector_gtv2di = 2688,
  CODE_FOR_vector_gtv4sf = 2689,
  CODE_FOR_vector_gtv2df = 2690,
  CODE_FOR_vector_gev4sf = 2691,
  CODE_FOR_vector_gev2df = 2692,
  CODE_FOR_vector_nltv16qi = 2693,
  CODE_FOR_vector_nltv8hi = 2694,
  CODE_FOR_vector_nltv4si = 2695,
  CODE_FOR_vector_nltv2di = 2696,
  CODE_FOR_vector_gtuv16qi = 2697,
  CODE_FOR_vector_gtuv8hi = 2698,
  CODE_FOR_vector_gtuv4si = 2699,
  CODE_FOR_vector_gtuv2di = 2700,
  CODE_FOR_vector_nltuv16qi = 2701,
  CODE_FOR_vector_nltuv8hi = 2702,
  CODE_FOR_vector_nltuv4si = 2703,
  CODE_FOR_vector_nltuv2di = 2704,
  CODE_FOR_vector_geuv16qi = 2705,
  CODE_FOR_vector_geuv8hi = 2706,
  CODE_FOR_vector_geuv4si = 2707,
  CODE_FOR_vector_geuv2di = 2708,
  CODE_FOR_vector_ngtv16qi = 2709,
  CODE_FOR_vector_ngtv8hi = 2710,
  CODE_FOR_vector_ngtv4si = 2711,
  CODE_FOR_vector_ngtv2di = 2712,
  CODE_FOR_vector_ngtuv16qi = 2713,
  CODE_FOR_vector_ngtuv8hi = 2714,
  CODE_FOR_vector_ngtuv4si = 2715,
  CODE_FOR_vector_ngtuv2di = 2716,
  CODE_FOR_vector_select_v16qi = 2717,
  CODE_FOR_vector_select_v8hi = 2718,
  CODE_FOR_vector_select_v4si = 2719,
  CODE_FOR_vector_select_v2di = 2720,
  CODE_FOR_vector_select_v4sf = 2721,
  CODE_FOR_vector_select_v2df = 2722,
  CODE_FOR_vector_select_v1ti = 2723,
  CODE_FOR_vector_select_ti = 2724,
  CODE_FOR_vector_select_kf = 2725,
  CODE_FOR_vector_select_tf = 2726,
  CODE_FOR_vector_select_v16qi_uns = 2727,
  CODE_FOR_vector_select_v8hi_uns = 2728,
  CODE_FOR_vector_select_v4si_uns = 2729,
  CODE_FOR_vector_select_v2di_uns = 2730,
  CODE_FOR_vector_select_v4sf_uns = 2731,
  CODE_FOR_vector_select_v2df_uns = 2732,
  CODE_FOR_vector_select_v1ti_uns = 2733,
  CODE_FOR_vector_select_ti_uns = 2734,
  CODE_FOR_vector_select_kf_uns = 2735,
  CODE_FOR_vector_select_tf_uns = 2736,
  CODE_FOR_vector_eq_v16qi_p = 2737,
  CODE_FOR_vector_eq_v8hi_p = 2738,
  CODE_FOR_vector_eq_v4si_p = 2739,
  CODE_FOR_vector_eq_v2di_p = 2740,
  CODE_FOR_vector_eq_v4sf_p = 2741,
  CODE_FOR_vector_eq_v2df_p = 2742,
  CODE_FOR_vector_ne_v4si_p = 2743,
  CODE_FOR_vector_ne_v8hi_p = 2744,
  CODE_FOR_vector_ne_v16qi_p = 2745,
  CODE_FOR_vector_ae_v4si_p = 2746,
  CODE_FOR_vector_ae_v8hi_p = 2747,
  CODE_FOR_vector_ae_v16qi_p = 2748,
  CODE_FOR_vector_nez_v4si_p = 2749,
  CODE_FOR_vector_nez_v8hi_p = 2750,
  CODE_FOR_vector_nez_v16qi_p = 2751,
  CODE_FOR_vector_ne_v2di_p = 2752,
  CODE_FOR_vector_ae_v2di_p = 2753,
  CODE_FOR_vector_ne_v4sf_p = 2754,
  CODE_FOR_vector_ne_v2df_p = 2755,
  CODE_FOR_vector_ae_v4sf_p = 2756,
  CODE_FOR_vector_ae_v2df_p = 2757,
  CODE_FOR_vector_gt_v16qi_p = 2758,
  CODE_FOR_vector_gt_v8hi_p = 2759,
  CODE_FOR_vector_gt_v4si_p = 2760,
  CODE_FOR_vector_gt_v2di_p = 2761,
  CODE_FOR_vector_gt_v4sf_p = 2762,
  CODE_FOR_vector_gt_v2df_p = 2763,
  CODE_FOR_vector_ge_v4sf_p = 2764,
  CODE_FOR_vector_ge_v2df_p = 2765,
  CODE_FOR_vector_gtu_v16qi_p = 2766,
  CODE_FOR_vector_gtu_v8hi_p = 2767,
  CODE_FOR_vector_gtu_v4si_p = 2768,
  CODE_FOR_vector_gtu_v2di_p = 2769,
  CODE_FOR_cr6_test_for_zero = 2770,
  CODE_FOR_cr6_test_for_zero_reverse = 2771,
  CODE_FOR_cr6_test_for_lt = 2772,
  CODE_FOR_cr6_test_for_lt_reverse = 2773,
  CODE_FOR_clzv16qi2 = 2774,
  CODE_FOR_clzv8hi2 = 2775,
  CODE_FOR_clzv4si2 = 2776,
  CODE_FOR_clzv2di2 = 2777,
  CODE_FOR_ctzv16qi2 = 2778,
  CODE_FOR_ctzv8hi2 = 2779,
  CODE_FOR_ctzv4si2 = 2780,
  CODE_FOR_ctzv2di2 = 2781,
  CODE_FOR_popcountv16qi2 = 2782,
  CODE_FOR_popcountv8hi2 = 2783,
  CODE_FOR_popcountv4si2 = 2784,
  CODE_FOR_popcountv2di2 = 2785,
  CODE_FOR_parityv8hi2 = 2786,
  CODE_FOR_parityv4si2 = 2787,
  CODE_FOR_parityv2di2 = 2788,
  CODE_FOR_parityv1ti2 = 2789,
  CODE_FOR_parityti2 = 2790,
  CODE_FOR_floatv4siv4sf2 = 2791,
  CODE_FOR_floatv2div2df2 = 2792,
  CODE_FOR_floatunsv4siv4sf2 = 2793,
  CODE_FOR_floatunsv2div2df2 = 2794,
  CODE_FOR_fix_truncv4sfv4si2 = 2795,
  CODE_FOR_fix_truncv2dfv2di2 = 2796,
  CODE_FOR_fixuns_truncv4sfv4si2 = 2797,
  CODE_FOR_fixuns_truncv2dfv2di2 = 2798,
  CODE_FOR_vec_initv16qi = 2799,
  CODE_FOR_vec_initv8hi = 2800,
  CODE_FOR_vec_initv4si = 2801,
  CODE_FOR_vec_initv2di = 2802,
  CODE_FOR_vec_initv4sf = 2803,
  CODE_FOR_vec_initv2df = 2804,
  CODE_FOR_vec_setv16qi = 2805,
  CODE_FOR_vec_setv8hi = 2806,
  CODE_FOR_vec_setv4si = 2807,
  CODE_FOR_vec_setv2di = 2808,
  CODE_FOR_vec_setv4sf = 2809,
  CODE_FOR_vec_setv2df = 2810,
  CODE_FOR_vec_extractv16qi = 2811,
  CODE_FOR_vec_extractv8hi = 2812,
  CODE_FOR_vec_extractv4si = 2813,
  CODE_FOR_vec_extractv2di = 2814,
  CODE_FOR_vec_extractv4sf = 2815,
  CODE_FOR_vec_extractv2df = 2816,
  CODE_FOR_vec_pack_trunc_v2df = 2817,
  CODE_FOR_vec_pack_sfix_trunc_v2df = 2818,
  CODE_FOR_vec_pack_ufix_trunc_v2df = 2819,
  CODE_FOR_vec_unpacks_hi_v4sf = 2820,
  CODE_FOR_vec_unpacks_lo_v4sf = 2821,
  CODE_FOR_vec_unpacks_float_hi_v4si = 2822,
  CODE_FOR_vec_unpacks_float_lo_v4si = 2823,
  CODE_FOR_vec_unpacku_float_hi_v4si = 2824,
  CODE_FOR_vec_unpacku_float_lo_v4si = 2825,
  CODE_FOR_vec_realign_load_v16qi = 2826,
  CODE_FOR_vec_realign_load_v8hi = 2827,
  CODE_FOR_vec_realign_load_v4si = 2828,
  CODE_FOR_vec_realign_load_v4sf = 2829,
  CODE_FOR_movmisalignv4si = 2830,
  CODE_FOR_movmisalignv4sf = 2831,
  CODE_FOR_movmisalignv2di = 2832,
  CODE_FOR_movmisalignv2df = 2833,
  CODE_FOR_movmisalignv1ti = 2834,
  CODE_FOR_movmisalignkf = 2835,
  CODE_FOR_movmisaligntf = 2836,
  CODE_FOR_vec_shr_v16qi = 2837,
  CODE_FOR_vec_shr_v8hi = 2838,
  CODE_FOR_vec_shr_v4si = 2839,
  CODE_FOR_vec_shr_v2di = 2840,
  CODE_FOR_vec_shr_v4sf = 2841,
  CODE_FOR_vec_shr_v2df = 2842,
  CODE_FOR_vec_shr_v1ti = 2843,
  CODE_FOR_vec_shr_ti = 2844,
  CODE_FOR_vec_shr_kf = 2845,
  CODE_FOR_vec_shr_tf = 2846,
  CODE_FOR_vrotlv16qi3 = 2847,
  CODE_FOR_vrotlv8hi3 = 2848,
  CODE_FOR_vrotlv4si3 = 2849,
  CODE_FOR_vrotlv2di3 = 2850,
  CODE_FOR_vashlv16qi3 = 2851,
  CODE_FOR_vashlv8hi3 = 2852,
  CODE_FOR_vashlv4si3 = 2853,
  CODE_FOR_vashlv2di3 = 2854,
  CODE_FOR_vlshrv16qi3 = 2855,
  CODE_FOR_vlshrv8hi3 = 2856,
  CODE_FOR_vlshrv4si3 = 2857,
  CODE_FOR_vlshrv2di3 = 2858,
  CODE_FOR_vashrv16qi3 = 2859,
  CODE_FOR_vashrv8hi3 = 2860,
  CODE_FOR_vashrv4si3 = 2861,
  CODE_FOR_vashrv2di3 = 2862,
  CODE_FOR_reduc_plus_scal_v4sf = 2863,
  CODE_FOR_reduc_smin_scal_v4sf = 2864,
  CODE_FOR_reduc_smax_scal_v4sf = 2865,
  CODE_FOR_reduc_plus_scal_v2df = 2866,
  CODE_FOR_reduc_smin_scal_v2df = 2867,
  CODE_FOR_reduc_smax_scal_v2df = 2868,
   CODE_FOR_absv2sf2 = CODE_FOR_nothing,
   CODE_FOR_negv2sf2 = CODE_FOR_nothing,
   CODE_FOR_addv2sf3 = CODE_FOR_nothing,
   CODE_FOR_subv2sf3 = CODE_FOR_nothing,
   CODE_FOR_mulv2sf3 = CODE_FOR_nothing,
   CODE_FOR_divv2sf3 = CODE_FOR_nothing,
  CODE_FOR_vsx_load_v16qi = 2869,
  CODE_FOR_vsx_load_v8hi = 2870,
  CODE_FOR_vsx_load_v4si = 2871,
  CODE_FOR_vsx_load_v2di = 2872,
  CODE_FOR_vsx_load_v4sf = 2873,
  CODE_FOR_vsx_load_v2df = 2874,
  CODE_FOR_vsx_load_v1ti = 2875,
  CODE_FOR_vsx_load_kf = 2876,
  CODE_FOR_vsx_load_tf = 2877,
  CODE_FOR_vsx_load_ti = 2878,
  CODE_FOR_vsx_store_v16qi = 2879,
  CODE_FOR_vsx_store_v8hi = 2880,
  CODE_FOR_vsx_store_v4si = 2881,
  CODE_FOR_vsx_store_v2di = 2882,
  CODE_FOR_vsx_store_v4sf = 2883,
  CODE_FOR_vsx_store_v2df = 2884,
  CODE_FOR_vsx_store_v1ti = 2885,
  CODE_FOR_vsx_store_kf = 2886,
  CODE_FOR_vsx_store_tf = 2887,
  CODE_FOR_vsx_store_ti = 2888,
  CODE_FOR_vsx_tdivdf3_fg = 2889,
  CODE_FOR_vsx_tdivv4sf3_fg = 2890,
  CODE_FOR_vsx_tdivv2df3_fg = 2891,
  CODE_FOR_vsx_tdivdf3_fe = 2892,
  CODE_FOR_vsx_tdivv4sf3_fe = 2893,
  CODE_FOR_vsx_tdivv2df3_fe = 2894,
  CODE_FOR_vsx_tsqrtdf2_fg = 2895,
  CODE_FOR_vsx_tsqrtv4sf2_fg = 2896,
  CODE_FOR_vsx_tsqrtv2df2_fg = 2897,
  CODE_FOR_vsx_tsqrtdf2_fe = 2898,
  CODE_FOR_vsx_tsqrtv4sf2_fe = 2899,
  CODE_FOR_vsx_tsqrtv2df2_fe = 2900,
  CODE_FOR_vsx_xvcvsxddp_scale = 2901,
  CODE_FOR_vsx_xvcvuxddp_scale = 2902,
  CODE_FOR_vsx_xvcvdpsxds_scale = 2903,
  CODE_FOR_vsx_xvcvdpuxds_scale = 2904,
  CODE_FOR_vsx_set_v1ti = 2905,
  CODE_FOR_vsx_set_v2df = 2906,
  CODE_FOR_vsx_set_v2di = 2907,
  CODE_FOR_vsx_xxpermdi_v16qi = 2908,
  CODE_FOR_vsx_xxpermdi_v8hi = 2909,
  CODE_FOR_vsx_xxpermdi_v4si = 2910,
  CODE_FOR_vsx_xxpermdi_v2di = 2911,
  CODE_FOR_vsx_xxpermdi_v4sf = 2912,
  CODE_FOR_vsx_xxpermdi_v2df = 2913,
  CODE_FOR_vsx_xxpermdi_v1ti = 2914,
  CODE_FOR_vsx_xxpermdi_ti = 2915,
  CODE_FOR_vsx_xxpermdi_kf = 2916,
  CODE_FOR_vsx_xxpermdi_tf = 2917,
  CODE_FOR_vsx_xxpermdi_v16qi_be = 2918,
  CODE_FOR_vsx_xxpermdi_v8hi_be = 2919,
  CODE_FOR_vsx_xxpermdi_v4si_be = 2920,
  CODE_FOR_vsx_xxpermdi_v2di_be = 2921,
  CODE_FOR_vsx_xxpermdi_v4sf_be = 2922,
  CODE_FOR_vsx_xxpermdi_v2df_be = 2923,
  CODE_FOR_vsx_xxpermdi_v1ti_be = 2924,
  CODE_FOR_vsx_xxpermdi_ti_be = 2925,
  CODE_FOR_vsx_xxpermdi_kf_be = 2926,
  CODE_FOR_vsx_xxpermdi_tf_be = 2927,
  CODE_FOR_vec_perm_constv2df = 2928,
  CODE_FOR_vec_perm_constv2di = 2929,
  CODE_FOR_vsx_extract_v16qi = 2930,
  CODE_FOR_vsx_extract_v8hi = 2931,
  CODE_FOR_vsx_extract_v4si = 2932,
  CODE_FOR_vsx_mergel_v2df = 2933,
  CODE_FOR_vsx_mergel_v2di = 2934,
  CODE_FOR_vsx_mergeh_v2df = 2935,
  CODE_FOR_vsx_mergeh_v2di = 2936,
  CODE_FOR_xscmpexpdp_eq = 2977,
  CODE_FOR_xscmpexpdp_lt = 2978,
  CODE_FOR_xscmpexpdp_gt = 2979,
  CODE_FOR_xscmpexpdp_unordered = 2980,
  CODE_FOR_xststdcsp = 2981,
  CODE_FOR_xststdcdp = 2982,
  CODE_FOR_xststdcnegsp = 2983,
  CODE_FOR_xststdcnegdp = 2984,
  CODE_FOR_lxvl = 2985,
  CODE_FOR_stxvl = 2986,
  CODE_FOR_vextract4b = 2987,
  CODE_FOR_vinsert4b = 2988,
  CODE_FOR_vinsert4b_di = 2989,
  CODE_FOR_p9_xxbrq_v16qi = 2990,
  CODE_FOR_altivec_mulv4sf3 = 2991,
  CODE_FOR_mulv4si3 = 2992,
  CODE_FOR_mulv8hi3 = 2993,
  CODE_FOR_altivec_vmrghb = 2994,
  CODE_FOR_altivec_vmrghh = 2995,
  CODE_FOR_altivec_vmrghw = 2996,
  CODE_FOR_altivec_vmrglb = 2997,
  CODE_FOR_altivec_vmrglh = 2998,
  CODE_FOR_altivec_vmrglw = 2999,
  CODE_FOR_vec_widen_umult_even_v16qi = 3000,
  CODE_FOR_vec_widen_smult_even_v16qi = 3001,
  CODE_FOR_vec_widen_umult_even_v8hi = 3002,
  CODE_FOR_vec_widen_smult_even_v8hi = 3003,
  CODE_FOR_vec_widen_umult_odd_v16qi = 3004,
  CODE_FOR_vec_widen_smult_odd_v16qi = 3005,
  CODE_FOR_vec_widen_umult_odd_v8hi = 3006,
  CODE_FOR_vec_widen_smult_odd_v8hi = 3007,
  CODE_FOR_altivec_vsum2sws = 3008,
  CODE_FOR_altivec_vsumsws = 3009,
  CODE_FOR_altivec_vspltb = 3010,
  CODE_FOR_altivec_vsplth = 3011,
  CODE_FOR_altivec_vspltw = 3012,
  CODE_FOR_altivec_vspltsf = 3013,
  CODE_FOR_altivec_vperm_v4si = 3014,
  CODE_FOR_altivec_vperm_v8hi = 3015,
  CODE_FOR_altivec_vperm_v16qi = 3016,
  CODE_FOR_altivec_vperm_v4sf = 3017,
  CODE_FOR_altivec_vperm_v2df = 3018,
  CODE_FOR_altivec_vperm_v2di = 3019,
  CODE_FOR_altivec_vperm_v1ti = 3020,
  CODE_FOR_altivec_vperm_ti = 3021,
  CODE_FOR_altivec_vperm_kf = 3022,
  CODE_FOR_altivec_vperm_tf = 3023,
  CODE_FOR_altivec_vperm_v4si_uns = 3024,
  CODE_FOR_altivec_vperm_v8hi_uns = 3025,
  CODE_FOR_altivec_vperm_v16qi_uns = 3026,
  CODE_FOR_altivec_vperm_v4sf_uns = 3027,
  CODE_FOR_altivec_vperm_v2df_uns = 3028,
  CODE_FOR_altivec_vperm_v2di_uns = 3029,
  CODE_FOR_altivec_vperm_v1ti_uns = 3030,
  CODE_FOR_altivec_vperm_ti_uns = 3031,
  CODE_FOR_altivec_vperm_kf_uns = 3032,
  CODE_FOR_altivec_vperm_tf_uns = 3033,
  CODE_FOR_vec_permv16qi = 3034,
  CODE_FOR_vec_perm_constv16qi = 3035,
  CODE_FOR_altivec_copysign_v4sf3 = 3036,
  CODE_FOR_altivec_lvsl = 3037,
  CODE_FOR_altivec_lvsr = 3038,
  CODE_FOR_build_vector_mask_for_load = 3039,
  CODE_FOR_altivec_lvewx = 3040,
  CODE_FOR_altivec_lvehx = 3041,
  CODE_FOR_altivec_lvebx = 3042,
  CODE_FOR_altivec_lvxl_v4si = 3043,
  CODE_FOR_altivec_lvxl_v8hi = 3044,
  CODE_FOR_altivec_lvxl_v16qi = 3045,
  CODE_FOR_altivec_lvxl_v4sf = 3046,
  CODE_FOR_altivec_lvxl_v2df = 3047,
  CODE_FOR_altivec_lvxl_v2di = 3048,
  CODE_FOR_altivec_lvxl_v1ti = 3049,
  CODE_FOR_altivec_lvxl_kf = 3050,
  CODE_FOR_altivec_lvxl_tf = 3051,
  CODE_FOR_altivec_stvxl_v4si = 3052,
  CODE_FOR_altivec_stvxl_v8hi = 3053,
  CODE_FOR_altivec_stvxl_v16qi = 3054,
  CODE_FOR_altivec_stvxl_v4sf = 3055,
  CODE_FOR_altivec_stvxl_v2df = 3056,
  CODE_FOR_altivec_stvxl_v2di = 3057,
  CODE_FOR_altivec_stvxl_v1ti = 3058,
  CODE_FOR_altivec_stvxl_kf = 3059,
  CODE_FOR_altivec_stvxl_tf = 3060,
  CODE_FOR_altivec_stvewx = 3061,
  CODE_FOR_altivec_stvehx = 3062,
  CODE_FOR_altivec_stvebx = 3063,
  CODE_FOR_absv4si2 = 3064,
  CODE_FOR_absv8hi2 = 3065,
  CODE_FOR_absv16qi2 = 3066,
  CODE_FOR_absv2di2 = 3067,
  CODE_FOR_nabsv4si2 = 3068,
  CODE_FOR_nabsv8hi2 = 3069,
  CODE_FOR_nabsv16qi2 = 3070,
  CODE_FOR_nabsv2di2 = 3071,
  CODE_FOR_altivec_absv4sf2 = 3072,
  CODE_FOR_altivec_abss_v4si = 3073,
  CODE_FOR_altivec_abss_v8hi = 3074,
  CODE_FOR_altivec_abss_v16qi = 3075,
  CODE_FOR_reduc_plus_scal_v8hi = 3076,
  CODE_FOR_reduc_plus_scal_v16qi = 3077,
  CODE_FOR_negv4si2 = 3078,
  CODE_FOR_negv8hi2 = 3079,
  CODE_FOR_negv16qi2 = 3080,
  CODE_FOR_negv2di2 = 3081,
  CODE_FOR_udot_prodv8hi = 3082,
  CODE_FOR_udot_prodv16qi = 3083,
  CODE_FOR_sdot_prodv8hi = 3084,
  CODE_FOR_widen_usumv8hi3 = 3085,
  CODE_FOR_widen_usumv16qi3 = 3086,
  CODE_FOR_widen_ssumv16qi3 = 3087,
  CODE_FOR_widen_ssumv8hi3 = 3088,
  CODE_FOR_vec_unpacks_hi_v4si = 3089,
  CODE_FOR_vec_unpacks_hi_v8hi = 3090,
  CODE_FOR_vec_unpacks_hi_v16qi = 3091,
  CODE_FOR_vec_unpacks_lo_v4si = 3092,
  CODE_FOR_vec_unpacks_lo_v8hi = 3093,
  CODE_FOR_vec_unpacks_lo_v16qi = 3094,
  CODE_FOR_vec_unpacku_hi_v16qi = 3095,
  CODE_FOR_vec_unpacku_hi_v8hi = 3096,
  CODE_FOR_vec_unpacku_lo_v16qi = 3097,
  CODE_FOR_vec_unpacku_lo_v8hi = 3098,
  CODE_FOR_vec_widen_umult_hi_v16qi = 3099,
  CODE_FOR_vec_widen_umult_lo_v16qi = 3100,
  CODE_FOR_vec_widen_smult_hi_v16qi = 3101,
  CODE_FOR_vec_widen_smult_lo_v16qi = 3102,
  CODE_FOR_vec_widen_umult_hi_v8hi = 3103,
  CODE_FOR_vec_widen_umult_lo_v8hi = 3104,
  CODE_FOR_vec_widen_smult_hi_v8hi = 3105,
  CODE_FOR_vec_widen_smult_lo_v8hi = 3106,
  CODE_FOR_vec_pack_trunc_v2di = 3107,
  CODE_FOR_vec_pack_trunc_v4si = 3108,
  CODE_FOR_vec_pack_trunc_v8hi = 3109,
  CODE_FOR_mulv16qi3 = 3110,
  CODE_FOR_altivec_negv4sf2 = 3111,
  CODE_FOR_vec_unpacks_float_hi_v8hi = 3112,
  CODE_FOR_vec_unpacks_float_lo_v8hi = 3113,
  CODE_FOR_vec_unpacku_float_hi_v8hi = 3114,
  CODE_FOR_vec_unpacku_float_lo_v8hi = 3115,
  CODE_FOR_vaduv4si3 = 3116,
  CODE_FOR_vaduv8hi3 = 3117,
  CODE_FOR_vaduv16qi3 = 3118,
  CODE_FOR_cmprb = 3119,
  CODE_FOR_cmprb2 = 3120,
  CODE_FOR_cmpeqb = 3121,
  CODE_FOR_bcdadd_eq = 3122,
  CODE_FOR_bcdsub_eq = 3123,
  CODE_FOR_bcdadd_lt = 3124,
  CODE_FOR_bcdsub_lt = 3125,
  CODE_FOR_bcdadd_gt = 3126,
  CODE_FOR_bcdsub_gt = 3127,
  CODE_FOR_bcdadd_unordered = 3128,
  CODE_FOR_bcdsub_unordered = 3129,
   CODE_FOR_vec_perm_constv2si = CODE_FOR_nothing,
   CODE_FOR_spe_evmergehi = CODE_FOR_nothing,
   CODE_FOR_spe_evmergehilo = CODE_FOR_nothing,
   CODE_FOR_spe_evmergelo = CODE_FOR_nothing,
   CODE_FOR_spe_evmergelohi = CODE_FOR_nothing,
   CODE_FOR_spe_fix_trunctfsi2 = CODE_FOR_nothing,
   CODE_FOR_spe_abstf2_cmp = CODE_FOR_nothing,
   CODE_FOR_spe_abstf2_tst = CODE_FOR_nothing,
   CODE_FOR_movv2si = CODE_FOR_nothing,
   CODE_FOR_movv1di = CODE_FOR_nothing,
   CODE_FOR_movv4hi = CODE_FOR_nothing,
   CODE_FOR_movv2sf = CODE_FOR_nothing,
  CODE_FOR_extendsdtd2 = 3130,
  CODE_FOR_negdd2 = 3131,
  CODE_FOR_absdd2 = 3132,
  CODE_FOR_negtd2 = 3133,
  CODE_FOR_abstd2 = 3134,
  CODE_FOR_dfptstsfi_eq_dd = 3135,
  CODE_FOR_dfptstsfi_lt_dd = 3136,
  CODE_FOR_dfptstsfi_gt_dd = 3137,
  CODE_FOR_dfptstsfi_unordered_dd = 3138,
  CODE_FOR_dfptstsfi_eq_td = 3139,
  CODE_FOR_dfptstsfi_lt_td = 3140,
  CODE_FOR_dfptstsfi_gt_td = 3141,
  CODE_FOR_dfptstsfi_unordered_td = 3142,
   CODE_FOR_vec_perm_constv2sf = CODE_FOR_nothing,
   CODE_FOR_vec_initv2sf = CODE_FOR_nothing,
   CODE_FOR_sminv2sf3 = CODE_FOR_nothing,
   CODE_FOR_smaxv2sf3 = CODE_FOR_nothing,
   CODE_FOR_reduc_smax_scal_v2sf = CODE_FOR_nothing,
   CODE_FOR_reduc_smin_scal_v2sf = CODE_FOR_nothing,
   CODE_FOR_reduc_plus_scal_v2sf = CODE_FOR_nothing,
   CODE_FOR_movmisalignv2sf = CODE_FOR_nothing,
   CODE_FOR_vcondv2sfv2sf = CODE_FOR_nothing,
  CODE_FOR_tabort = 3143,
  CODE_FOR_tabortwc = 3144,
  CODE_FOR_tabortdc = 3145,
  CODE_FOR_tabortwci = 3146,
  CODE_FOR_tabortdci = 3147,
  CODE_FOR_tbegin = 3148,
  CODE_FOR_tcheck = 3149,
  CODE_FOR_tend = 3150,
  CODE_FOR_trechkpt = 3151,
  CODE_FOR_treclaim = 3152,
  CODE_FOR_tsr = 3153,
  CODE_FOR_ttest = 3154
};

const unsigned int NUM_INSN_CODES = 3155;
#endif /* GCC_INSN_CODES_H */
